<?php
/**
 * Plugin support: WooCommerce
 *
 * @package WordPress
 * @subpackage ThemeREX Addons
 * @since v1.5
 */

// Check if plugin installed and activated

if ( !function_exists( 'trx_addons_exists_responsive_poll' ) ) {
	function trx_addons_exists_responsive_poll() {
		return class_exists('Weblator_Polling');
	}
}



// One-click import support
//------------------------------------------------------------------------

// Check plugin in the required plugins
if ( !function_exists( 'trx_addons_responsive_poll_importer_required_plugins' ) ) {
	if (is_admin()) add_filter( 'trx_addons_filter_importer_required_plugins',	'trx_addons_responsive_poll_importer_required_plugins', 10, 2 );
	function trx_addons_responsive_poll_importer_required_plugins($not_installed='', $list='') {
		if (strpos($list, 'responsive-poll')!==false && !trx_addons_exists_responsive_poll() )
			$not_installed .= '<br>' . esc_html__('Responsive Poll', 'trx_addons');
		return $not_installed;
	}
}

// Set plugin's specific importer options
if ( !function_exists( 'trx_addons_responsive_poll_importer_set_options' ) ) {
	if (is_admin()) add_filter( 'trx_addons_filter_importer_options',	'trx_addons_responsive_poll_importer_set_options' );
	function trx_addons_responsive_poll_importer_set_options($options=array()) {
		if ( trx_addons_exists_responsive_poll() && in_array('responsive-poll', $options['required_plugins']) ) {
			if (is_array($options['files']) && count($options['files']) > 0) {
				foreach ($options['files'] as $k => $v) {
					$options['files'][$k]['file_with_responsive-poll'] = str_replace('name.ext', 'responsive-poll.txt', $v['file_with_']);
				}
			}
		}
		return $options;
	}
}

// Add checkbox to the one-click importer
if ( !function_exists( 'trx_addons_responsive_poll_importer_show_params' ) ) {
	if (is_admin()) add_action( 'trx_addons_action_importer_params',	'trx_addons_responsive_poll_importer_show_params', 10, 1 );
	function trx_addons_responsive_poll_importer_show_params($importer) {
		if ( trx_addons_exists_responsive_poll() && in_array('responsive-poll', $importer->options['required_plugins']) ) {
			$importer->show_importer_params(array(
				'slug' => 'responsive-poll',
				'title' => esc_html__('Import Responsive Poll', 'trx_addons'),
				'part' => 1
			));
		}
	}
}

// Import posts
if ( !function_exists( 'trx_addons_responsive_poll_importer_import' ) ) {
	if (is_admin()) add_action( 'trx_addons_action_importer_import',	'trx_addons_responsive_poll_importer_import', 10, 2 );
	function trx_addons_responsive_poll_importer_import($importer, $action) {
		if ( trx_addons_exists_responsive_poll() && in_array('responsive-poll', $importer->options['required_plugins']) ) {
			if ( $action == 'import_responsive-poll' ) {
				$importer->response['start_from_id'] = 0;
				$importer->import_dump('responsive-poll', esc_html__('Responsive Poll', 'trx_addons'));
			}
		}
	}
}

// Display import progress
if ( !function_exists( 'trx_addons_responsive_poll_importer_import_fields' ) ) {
	if (is_admin()) add_action( 'trx_addons_action_importer_import_fields',	'trx_addons_responsive_poll_importer_import_fields', 10, 1 );
	function trx_addons_responsive_poll_importer_import_fields($importer) {
		if ( trx_addons_exists_responsive_poll() && in_array('responsive-poll', $importer->options['required_plugins']) ) {
			$importer->show_importer_fields(array(
				'slug'=>'responsive-poll',
				'title' => esc_html__('Responsive Poll', 'trx_addons')
				)
			);
		}
	}
}

// Export posts
if ( !function_exists( 'trx_addons_responsive_poll_importer_export' ) ) {
	if (is_admin()) add_action( 'trx_addons_action_importer_export',	'trx_addons_responsive_poll_importer_export', 10, 1 );
	function trx_addons_responsive_poll_importer_export($importer) {
		if ( trx_addons_exists_responsive_poll() && in_array('responsive-poll', $importer->options['required_plugins']) ) {
			trx_addons_fpc(TRX_ADDONS_PLUGIN_DIR . 'importer/export/responsive-poll.txt', serialize( array(
				"weblator_chart_type"				=> $importer->export_dump("weblator_chart_type"),
				"weblator_polls"	                => $importer->export_dump("weblator_polls"),
				"weblator_poll_options"				=> $importer->export_dump("weblator_poll_options"),
				"weblator_poll_style_dropdowns"		=> $importer->export_dump("weblator_poll_style_dropdowns"),
				"weblator_poll_votes"				=> $importer->export_dump("weblator_poll_votes"),
                "weblator_style_chart_link"			=> $importer->export_dump("weblator_style_chart_link"),
                "weblator_style_options"			=> $importer->export_dump("weblator_style_options"),
                "weblator_style_values"				=> $importer->export_dump("weblator_style_values")
				) )
			);
		}
	}
}

// Display exported data in the fields
if ( !function_exists( 'trx_addons_responsive_poll_importer_export_fields' ) ) {
	if (is_admin()) add_action( 'trx_addons_action_importer_export_fields',	'trx_addons_responsive_poll_importer_export_fields', 10, 1 );
	function trx_addons_responsive_poll_importer_export_fields($importer) {
		if ( trx_addons_exists_responsive_poll() && in_array('responsive-poll', $importer->options['required_plugins']) ) {
			$importer->show_exporter_fields(array(
				'slug'	=> 'responsive-poll',
				'title' => esc_html__('Responsive Poll', 'trx_addons')
				)
			);
		}
	}
}
?>