<?php

// Width and height params
if ( !function_exists( 'themerex_vc_width' ) ) {
	function themerex_vc_width($w='') {
		return array(
			"param_name" => "width",
			"heading" => __("Width", "themerex"),
			"description" => __("Width (in pixels or percent) of the current element", "themerex"),
			"group" => __('Size &amp; Margins', 'trx_utils'),
			"value" => $w,
			"type" => "textfield"
		);
	}
}
if ( !function_exists( 'themerex_vc_height' ) ) {
	function themerex_vc_height($h='') {
		return array(
			"param_name" => "height",
			"heading" => __("Height", "themerex"),
			"description" => __("Height (only in pixels) of the current element", "themerex"),
			"group" => __('Size &amp; Margins', 'trx_utils'),
			"value" => $h,
			"type" => "textfield"
		);
	}
}

// Load scripts and styles for VC support
if ( !function_exists( 'themerex_shortcodes_vc_scripts_admin' ) ) {
	//add_action( 'admin_enqueue_scripts', 'themerex_shortcodes_vc_scripts_admin' );
	function themerex_shortcodes_vc_scripts_admin() {
		// Include CSS 
		wp_enqueue_style ( 'shortcodes_vc-style', trx_addons_get_file_url('shortcodes/shortcodes_vc_admin.css'), array(), null );
		// Include JS
		wp_enqueue_script( 'shortcodes_vc-script', trx_addons_get_file_url('shortcodes/shortcodes_vc_admin.js'), array(), null, true );
	}
}

// Load scripts and styles for VC support
if ( !function_exists( 'themerex_shortcodes_vc_scripts_front' ) ) {
	//add_action( 'wp_enqueue_scripts', 'themerex_shortcodes_vc_scripts_front' );
	function themerex_shortcodes_vc_scripts_front() {
		if (themerex_vc_is_frontend()) {
			// Include CSS 
			wp_enqueue_style ( 'shortcodes-vc-style', trx_addons_get_file_url('shortcodes/shortcodes_vc_front.css'), array(), null );
		}
	}
}

// Add init script into shortcodes output in VC frontend editor
if ( !function_exists( 'themerex_shortcodes_vc_add_init_script' ) ) {
	//add_filter('themerex_shortcode_output', 'themerex_shortcodes_vc_add_init_script', 10, 4);
	function themerex_shortcodes_vc_add_init_script($output, $tag='', $atts=array(), $content='') {
		if ( (isset($_GET['vc_editable']) && $_GET['vc_editable']=='true') && (isset($_POST['action']) && $_POST['action']=='vc_load_shortcode')
				&& ( isset($_POST['shortcodes'][0]['tag']) && $_POST['shortcodes'][0]['tag']==$tag )
		) {
			if (themerex_strpos($output, 'themerex_vc_init_shortcodes')===false) {
				$id = "themerex_vc_init_shortcodes_".str_replace('.', '', mt_rand());
				$output .= '
					<script id="'.esc_attr($id).'">
						try {
							themerex_init_post_formats();
							themerex_init_shortcodes(jQuery("body").eq(0));
							themerex_scroll_actions();
						} catch (e) { };
					</script>
				';
			}
		}
		return $output;
	}
}

// Prevent simultaneous editing of posts for Gutenberg and other PageBuilders (VC, Elementor)
if ( ! function_exists( 'trx_addons_gutenberg_disable_cpt' ) ) {
    add_action( 'current_screen', 'trx_addons_gutenberg_disable_cpt' );
    function trx_addons_gutenberg_disable_cpt() {
        $safe_pb = array('vc');
        if ( !empty($safe_pb) && function_exists( 'the_gutenberg_project' ) && function_exists( 'register_block_type' ) ) {
            $current_post_type = get_current_screen()->post_type;
            $disable = false;
            if ( !$disable && in_array('vc', $safe_pb) && function_exists('vc_editor_post_types') ) {
                $post_types = vc_editor_post_types();
                $disable = is_array($post_types) && in_array($current_post_type, $post_types);
            }
            if ( $disable ) {
                remove_filter( 'replace_editor', 'gutenberg_init' );
                remove_action( 'load-post.php', 'gutenberg_intercept_edit_post' );
                remove_action( 'load-post-new.php', 'gutenberg_intercept_post_new' );
                remove_action( 'admin_init', 'gutenberg_add_edit_link_filters' );
                remove_filter( 'admin_url', 'gutenberg_modify_add_new_button_url' );
                remove_action( 'admin_print_scripts-edit.php', 'gutenberg_replace_default_add_new_button' );
                remove_action( 'admin_enqueue_scripts', 'gutenberg_editor_scripts_and_styles' );
                remove_filter( 'screen_options_show_screen', '__return_false' );
            }
        }
    }
}


/* Theme setup section
-------------------------------------------------------------------- */

if ( !function_exists( 'themerex_shortcodes_vc_theme_setup' ) ) {
	//if ( themerex_vc_is_frontend() )
	if ( (isset($_GET['vc_editable']) && $_GET['vc_editable']=='true') || (isset($_GET['vc_action']) && $_GET['vc_action']=='vc_inline') )
		add_action( 'themerex_action_before_init_theme', 'themerex_shortcodes_vc_theme_setup', 20 );
	else
		add_action( 'themerex_action_after_init_theme', 'themerex_shortcodes_vc_theme_setup' );
	function themerex_shortcodes_vc_theme_setup() {
		if (themerex_shortcodes_is_used()) {
			// Set VC as main editor for the theme
			vc_set_as_theme( true );
			
			// Enable VC on follow post types
			vc_set_default_editor_post_types( array('page', 'team', 'courses') );
			
			// Disable frontend editor
			//vc_disable_frontend();

			// Load scripts and styles for VC support
			add_action( 'wp_enqueue_scripts',		'themerex_shortcodes_vc_scripts_front');
			add_action( 'admin_enqueue_scripts',	'themerex_shortcodes_vc_scripts_admin' );

			// Add init script into shortcodes output in VC frontend editor
			add_filter('themerex_shortcode_output', 'themerex_shortcodes_vc_add_init_script', 10, 4);
/*
			// Remove standard VC shortcodes
			vc_remove_element("vc_button");
			vc_remove_element("vc_posts_slider");
			vc_remove_element("vc_gmaps");
			vc_remove_element("vc_teaser_grid");
			vc_remove_element("vc_progress_bar");
			vc_remove_element("vc_facebook");
			vc_remove_element("vc_tweetmeme");
			vc_remove_element("vc_googleplus");
			vc_remove_element("vc_facebook");
			vc_remove_element("vc_pinterest");
			vc_remove_element("vc_message");
			vc_remove_element("vc_posts_grid");
			vc_remove_element("vc_carousel");
			vc_remove_element("vc_flickr");
			vc_remove_element("vc_tour");
			vc_remove_element("vc_separator");
			vc_remove_element("vc_single_image");
			vc_remove_element("vc_cta_button");
//			vc_remove_element("vc_accordion");
//			vc_remove_element("vc_accordion_tab");
			vc_remove_element("vc_toggle");
			vc_remove_element("vc_tabs");
			vc_remove_element("vc_tab");
			vc_remove_element("vc_images_carousel");
*/
			// Remove standard WP widgets
			vc_remove_element("vc_wp_archives");
			vc_remove_element("vc_wp_calendar");
			vc_remove_element("vc_wp_categories");
			vc_remove_element("vc_wp_custommenu");
			vc_remove_element("vc_wp_links");
			vc_remove_element("vc_wp_meta");
			vc_remove_element("vc_wp_pages");
			vc_remove_element("vc_wp_posts");
			vc_remove_element("vc_wp_recentcomments");
			vc_remove_element("vc_wp_rss");
			vc_remove_element("vc_wp_search");
			vc_remove_element("vc_wp_tagcloud");
			vc_remove_element("vc_wp_text");
			
			global $THEMEREX_GLOBALS;
			
			$THEMEREX_GLOBALS['vc_params'] = array(
				
				// Common arrays and strings
				'category' => __("ThemeREX shortcodes", "themerex"),
			
				// Current element id
				'id' => array(
					"param_name" => "id",
					"heading" => __("Element ID", "themerex"),
					"description" => __("ID for current element", "themerex"),
					"group" => __('Size &amp; Margins', 'trx_utils'),
					"value" => "",
					"type" => "textfield"
				),
			
				// Current element class
				'class' => array(
					"param_name" => "class",
					"heading" => __("Element CSS class", "themerex"),
					"description" => __("CSS class for current element", "themerex"),
					"group" => __('Size &amp; Margins', 'trx_utils'),
					"value" => "",
					"type" => "textfield"
				),

				// Current element animation
				'animation' => array(
					"param_name" => "animation",
					"heading" => __("Animation", "themerex"),
					"description" => __("Select animation while object enter in the visible area of page", "themerex"),
					"class" => "",
					"value" => array_flip($THEMEREX_GLOBALS['sc_params']['animations']),
					"type" => "dropdown"
				),
			
				// Current element style
				'css' => array(
					"param_name" => "css",
					"heading" => __("CSS styles", "themerex"),
					"description" => __("Any additional CSS rules (if need)", "themerex"),
					"group" => __('Size &amp; Margins', 'trx_utils'),
					"class" => "",
					"value" => "",
					"type" => "textfield"
				),
			
				// Margins params
				'margin_top' => array(
					"param_name" => "top",
					"heading" => __("Top margin", "themerex"),
					"description" => __("Top margin (in pixels).", "themerex"),
					"group" => __('Size &amp; Margins', 'trx_utils'),
					"value" => "",
					"type" => "textfield"
				),
			
				'margin_bottom' => array(
					"param_name" => "bottom",
					"heading" => __("Bottom margin", "themerex"),
					"description" => __("Bottom margin (in pixels).", "themerex"),
					"group" => __('Size &amp; Margins', 'trx_utils'),
					"value" => "",
					"type" => "textfield"
				),
			
				'margin_left' => array(
					"param_name" => "left",
					"heading" => __("Left margin", "themerex"),
					"description" => __("Left margin (in pixels).", "themerex"),
					"group" => __('Size &amp; Margins', 'trx_utils'),
					"value" => "",
					"type" => "textfield"
				),
				
				'margin_right' => array(
					"param_name" => "right",
					"heading" => __("Right margin", "themerex"),
					"description" => __("Right margin (in pixels).", "themerex"),
					"group" => __('Size &amp; Margins', 'trx_utils'),
					"value" => "",
					"type" => "textfield"
				)
			);
	
	
	
			// Accordion
			//-------------------------------------------------------------------------------------
			vc_map( array(
				"base" => "trx_accordion",
				"name" => __("Accordion", "themerex"),
				"description" => __("Accordion items", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_accordion',
				"class" => "trx_sc_collection trx_sc_accordion",
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => false,
				"as_parent" => array('only' => 'trx_accordion_item'),	// Use only|except attributes to limit child shortcodes (separate multiple values with comma)
				"params" => array(
					array(
						"param_name" => "counter",
						"heading" => __("Counter", "themerex"),
						"description" => __("Display counter before each accordion title", "themerex"),
						"class" => "",
						"value" => array("Add item numbers before each element" => "on" ),
						"type" => "checkbox"
					),
					array(
						"param_name" => "initial",
						"heading" => __("Initially opened item", "themerex"),
						"description" => __("Number of initially opened item", "themerex"),
						"class" => "",
						"value" => 1,
						"type" => "textfield"
					),
					array(
						"param_name" => "icon_closed",
						"heading" => __("Icon while closed", "themerex"),
						"description" => __("Select icon for the closed accordion item from Fontello icons set", "themerex"),
						"class" => "",
						"value" => $THEMEREX_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					array(
						"param_name" => "icon_opened",
						"heading" => __("Icon while opened", "themerex"),
						"description" => __("Select icon for the opened accordion item from Fontello icons set", "themerex"),
						"class" => "",
						"value" => $THEMEREX_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
				'default_content' => '
					[trx_accordion_item title="' . __( 'Item 1 title', 'trx_utils' ) . '"][/trx_accordion_item]
					[trx_accordion_item title="' . __( 'Item 2 title', 'trx_utils' ) . '"][/trx_accordion_item]
				',
				"custom_markup" => '
					<div class="wpb_accordion_holder wpb_holder clearfix vc_container_for_children">
						%content%
					</div>
					<div class="tab_controls">
						<button class="add_tab" title="'.__("Add item", "themerex").'">'.__("Add item", "themerex").'</button>
					</div>
				',
				'js_view' => 'VcTrxAccordionView'
			) );
			
			
			vc_map( array(
				"base" => "trx_accordion_item",
				"name" => __("Accordion item", "themerex"),
				"description" => __("Inner accordion item", "themerex"),
				"show_settings_on_create" => true,
				"content_element" => true,
				"is_container" => true,
				'icon' => 'icon_trx_accordion_item',
				"as_child" => array('only' => 'trx_accordion'), 	// Use only|except attributes to limit parent (separate multiple values with comma)
				"as_parent" => array('except' => 'trx_accordion'),
				"params" => array(
					array(
						"param_name" => "title",
						"heading" => __("Title", "themerex"),
						"description" => __("Title for current accordion item", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "icon_closed",
						"heading" => __("Icon while closed", "themerex"),
						"description" => __("Select icon for the closed accordion item from Fontello icons set", "themerex"),
						"class" => "",
						"value" => $THEMEREX_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					array(
						"param_name" => "icon_opened",
						"heading" => __("Icon while opened", "themerex"),
						"description" => __("Select icon for the opened accordion item from Fontello icons set", "themerex"),
						"class" => "",
						"value" => $THEMEREX_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
			  'js_view' => 'VcTrxAccordionTabView'
			) );

			class WPBakeryShortCode_Trx_Accordion extends Themerex_Vc_ShortCodeAccordion {}
			class WPBakeryShortCode_Trx_Accordion_Item extends Themerex_Vc_ShortCodeAccordionItem {}
			

			
			// Anchor
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_anchor",
				"name" => __("Anchor", "themerex"),
				"description" => __("Insert anchor for the TOC (table of content)", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_anchor',
				"class" => "trx_sc_single trx_sc_anchor",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "icon",
						"heading" => __("Anchor's icon", "themerex"),
						"description" => __("Select icon for the anchor from Fontello icons set", "themerex"),
						"class" => "",
						"value" => $THEMEREX_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					array(
						"param_name" => "title",
						"heading" => __("Short title", "themerex"),
						"description" => __("Short title of the anchor (for the table of content)", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "description",
						"heading" => __("Long description", "themerex"),
						"description" => __("Description for the popup (then hover on the icon). You can use '{' and '}' - make the text italic, '|' - insert line break", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "url",
						"heading" => __("External URL", "themerex"),
						"description" => __("External URL for this TOC item", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "separator",
						"heading" => __("Add separator", "themerex"),
						"description" => __("Add separator under item in the TOC", "themerex"),
						"class" => "",
						"value" => array("Add separator" => "yes" ),
						"type" => "checkbox"
					),
					$THEMEREX_GLOBALS['vc_params']['id']
				),
			) );
			
			class WPBakeryShortCode_Trx_Anchor extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Audio
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_audio",
				"name" => __("Audio", "themerex"),
				"description" => __("Insert audio player", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_audio',
				"class" => "trx_sc_single trx_sc_audio",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "url",
						"heading" => __("URL for audio file", "themerex"),
						"description" => __("Put here URL for audio file", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "image",
						"heading" => __("Cover image", "themerex"),
						"description" => __("Select or upload image or write URL from other site for audio cover", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					array(
						"param_name" => "title",
						"heading" => __("Title", "themerex"),
						"description" => __("Title of the audio file", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "author",
						"heading" => __("Author", "themerex"),
						"description" => __("Author of the audio file", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "controls",
						"heading" => __("Controls", "themerex"),
						"description" => __("Show/hide controls", "themerex"),
						"class" => "",
						"value" => array("Hide controls" => "hide" ),
						"type" => "checkbox"
					),
					array(
						"param_name" => "autoplay",
						"heading" => __("Autoplay", "themerex"),
						"description" => __("Autoplay audio on page load", "themerex"),
						"class" => "",
						"value" => array("Autoplay" => "on" ),
						"type" => "checkbox"
					),
					array(
						"param_name" => "align",
						"heading" => __("Alignment", "themerex"),
						"description" => __("Select block alignment", "themerex"),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['align']),
						"type" => "dropdown"
					),
					themerex_vc_width(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
			) );
			
			class WPBakeryShortCode_Trx_Audio extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Block
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_block",
				"name" => __("Block container", "themerex"),
				"description" => __("Container for any block ([section] analog - to enable nesting)", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_block',
				"class" => "trx_sc_collection trx_sc_block",
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "dedicated",
						"heading" => __("Dedicated", "themerex"),
						"description" => __("Use this block as dedicated content - show it before post title on single page", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array(__('Use as dedicated content', 'trx_utils') => 'yes'),
						"type" => "checkbox"
					),
					array(
						"param_name" => "align",
						"heading" => __("Alignment", "themerex"),
						"description" => __("Select block alignment", "themerex"),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['align']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "bg_color",
						"heading" => __("Background color", "themerex"),
						"description" => __("Any background color for this section", "themerex"),
					//	"group" => __('Colors and Images', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "bg_image",
						"heading" => __("Background image URL", "themerex"),
						"description" => __("Select background image from library for this section", "themerex"),
					//	"group" => __('Colors and Images', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					array(
						"param_name" => "bg_padding",
						"heading" => __("Padding", "themerex"),
						"description" => __("Container padding", "themerex"),
					//	"group" => __('Colors and Images', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					themerex_vc_width(),
					themerex_vc_height(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			class WPBakeryShortCode_Trx_Block extends Themerex_Vc_ShortCodeCollection {}
			

			
			// Blogger
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_blogger",
				"name" => __("Blogger", "themerex"),
				"description" => __("Insert posts (pages) in many styles from desired categories or directly from ids", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_blogger',
				"class" => "trx_sc_single trx_sc_blogger",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "style",
						"heading" => __("Output style", "themerex"),
						"description" => __("Select desired style for posts output", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['blogger_styles']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "filters",
						"heading" => __("Show filters", "themerex"),
						"description" => __("Use post's tags or categories as filter buttons", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['filters']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "hover",
						"heading" => __("Hover effect", "themerex"),
						"description" => __("Select hover effect (only if style=Portfolio)", "themerex"),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['hovers']),
						'dependency' => array(
							'element' => 'style',
							'value' => array('portfolio_2','portfolio_3','portfolio_4','grid_2','grid_3','grid_4','square_2','square_3','square_4','courses_2','courses_3','courses_4')
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "hover_dir",
						"heading" => __("Hover direction", "themerex"),
						"description" => __("Select hover direction (only if style=Portfolio and hover=Circle|Square)", "themerex"),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['hovers_dir']),
						'dependency' => array(
							'element' => 'style',
							'value' => array('portfolio_2','portfolio_3','portfolio_4','grid_2','grid_3','grid_4','square_2','square_3','square_4','courses_2','courses_3','courses_4')
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "location",
						"heading" => __("Dedicated content location", "themerex"),
						"description" => __("Select position for dedicated content (only for style=excerpt)", "themerex"),
						"class" => "",
						'dependency' => array(
							'element' => 'style',
							'value' => array('excerpt')
						),
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['locations']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "dir",
						"heading" => __("Posts direction", "themerex"),
						"description" => __("Display posts in horizontal or vertical direction", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['dir']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "rating",
						"heading" => __("Show rating stars", "themerex"),
						"description" => __("Show rating stars under post's header", "themerex"),
						"group" => __('Details', 'trx_utils'),
						"class" => "",
						"value" => array(__('Show rating', 'trx_utils') => 'yes'),
						"type" => "checkbox"
					),
					array(
						"param_name" => "info",
						"heading" => __("Show post info block", "themerex"),
						"description" => __("Show post info block (author, date, tags, etc.)", "themerex"),
						"class" => "",
						"value" => array(__('Show info', 'trx_utils') => 'yes'),
						"type" => "checkbox"
					),
					array(
						"param_name" => "descr",
						"heading" => __("Description length", "themerex"),
						"description" => __("How many characters are displayed from post excerpt? If 0 - don't show description", "themerex"),
						"group" => __('Details', 'trx_utils'),
						"class" => "",
						"value" => 0,
						"type" => "textfield"
					),
					array(
						"param_name" => "links",
						"heading" => __("Allow links to the post", "themerex"),
						"description" => __("Allow links to the post from each blogger item", "themerex"),
						"group" => __('Details', 'trx_utils'),
						"class" => "",
						"value" => array(__('Allow links', 'trx_utils') => 'yes'),
						"type" => "checkbox"
					),
					array(
						"param_name" => "readmore",
						"heading" => __("More link text", "themerex"),
						"description" => __("Read more link text. If empty - show 'More', else - used as link text", "themerex"),
						"group" => __('Details', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "post_type",
						"heading" => __("Post type", "themerex"),
						"description" => __("Select post type to show", "themerex"),
						"group" => __('Query', 'trx_utils'),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['posts_types']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "ids",
						"heading" => __("Post IDs list", "themerex"),
						"description" => __("Comma separated list of posts ID. If set - parameters above are ignored!", "themerex"),
						"group" => __('Query', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "cat",
						"heading" => __("Categories list", "themerex"),
						"description" => __("Put here comma separated category slugs or ids. If empty - show posts from any category or from IDs list", "themerex"),
						'dependency' => array(
							'element' => 'ids',
							'is_empty' => true
						),
						"group" => __('Query', 'trx_utils'),
						"class" => "",
						"value" => array_flip(themerex_array_merge(array(0 => __('- Select category -', 'trx_utils')), $THEMEREX_GLOBALS['sc_params']['categories'])),
						"type" => "dropdown"
					),
					array(
						"param_name" => "count",
						"heading" => __("Total posts to show", "themerex"),
						"description" => __("How many posts will be displayed? If used IDs - this parameter ignored.", "themerex"),
						'dependency' => array(
							'element' => 'ids',
							'is_empty' => true
						),
						"admin_label" => true,
						"group" => __('Query', 'trx_utils'),
						"class" => "",
						"value" => 3,
						"type" => "textfield"
					),
					array(
						"param_name" => "columns",
						"heading" => __("Columns number", "themerex"),
						"description" => __("How many columns used to display posts?", "themerex"),
						'dependency' => array(
							'element' => 'dir',
							'value' => 'horizontal'
						),
						"group" => __('Query', 'trx_utils'),
						"class" => "",
						"value" => 3,
						"type" => "textfield"
					),
					array(
						"param_name" => "offset",
						"heading" => __("Offset before select posts", "themerex"),
						"description" => __("Skip posts before select next part.", "themerex"),
						'dependency' => array(
							'element' => 'ids',
							'is_empty' => true
						),
						"group" => __('Query', 'trx_utils'),
						"class" => "",
						"value" => 0,
						"type" => "textfield"
					),
					array(
						"param_name" => "orderby",
						"heading" => __("Post order by", "themerex"),
						"description" => __("Select desired posts sorting method", "themerex"),
						"class" => "",
						"group" => __('Query', 'trx_utils'),
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['sorting']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "order",
						"heading" => __("Post order", "themerex"),
						"description" => __("Select desired posts order", "themerex"),
						"class" => "",
						"group" => __('Query', 'trx_utils'),
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['ordering']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "only",
						"heading" => __("Select posts only", "themerex"),
						"description" => __("Select posts only with reviews, videos, audios, thumbs or galleries", "themerex"),
						"class" => "",
						"group" => __('Query', 'trx_utils'),
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['formats']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "scroll",
						"heading" => __("Use scroller", "themerex"),
						"description" => __("Use scroller to show all posts", "themerex"),
						"group" => __('Scroll', 'trx_utils'),
						"class" => "",
						"value" => array(__('Use scroller', 'trx_utils') => 'yes'),
						"type" => "checkbox"
					),
					array(
						"param_name" => "controls",
						"heading" => __("Show slider controls", "themerex"),
						"description" => __("Show arrows to control scroll slider", "themerex"),
						"group" => __('Scroll', 'trx_utils'),
						"class" => "",
						"value" => array(__('Show controls', 'trx_utils') => 'yes'),
						"type" => "checkbox"
					),
					themerex_vc_width(),
					themerex_vc_height(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
			) );
			
			class WPBakeryShortCode_Trx_Blogger extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Br
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_br",
				"name" => __("Line break", "themerex"),
				"description" => __("Line break or Clear Floating", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_br',
				"class" => "trx_sc_single trx_sc_br",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "clear",
						"heading" => __("Clear floating", "themerex"),
						"description" => __("Select clear side (if need)", "themerex"),
						"class" => "",
						"value" => "",
						"value" => array(
							__('None', 'trx_utils') => 'none',
							__('Left', 'trx_utils') => 'left',
							__('Right', 'trx_utils') => 'right',
							__('Both', 'trx_utils') => 'both'
						),
						"type" => "dropdown"
					)
				)
			) );
			
			class WPBakeryShortCode_Trx_Br extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Button
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_button",
				"name" => __("Button", "themerex"),
				"description" => __("Button with link", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_button',
				"class" => "trx_sc_single trx_sc_button",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "content",
						"heading" => __("Caption", "themerex"),
						"description" => __("Button caption", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "size",
						"heading" => __("Button's size", "themerex"),
						"description" => __("Select button's size", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							__('Small', 'trx_utils') => 'mini',
							__('Medium', 'trx_utils') => 'medium',
							__('Large', 'trx_utils') => 'big'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "icon",
						"heading" => __("Button's icon", "themerex"),
						"description" => __("Select icon for the title from Fontello icons set", "themerex"),
						"class" => "",
						"value" => $THEMEREX_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					array(
						"param_name" => "color",
						"heading" => __("Button's text color", "themerex"),
						"description" => __("Any color for button's caption", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "bg_color",
						"heading" => __("Button's backcolor", "themerex"),
						"description" => __("Any color for button's background", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "align",
						"heading" => __("Button's alignment", "themerex"),
						"description" => __("Align button to left, center or right", "themerex"),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['align']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "link",
						"heading" => __("Link URL", "themerex"),
						"description" => __("URL for the link on button click", "themerex"),
						"class" => "",
						"group" => __('Link', 'trx_utils'),
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "target",
						"heading" => __("Link target", "themerex"),
						"description" => __("Target for the link on button click", "themerex"),
						"class" => "",
						"group" => __('Link', 'trx_utils'),
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "rel",
						"heading" => __("Rel attribute", "themerex"),
						"description" => __("Rel attribute for the button's link (if need", "themerex"),
						"class" => "",
						"group" => __('Link', 'trx_utils'),
						"value" => "",
						"type" => "textfield"
					),
					themerex_vc_width(),
					themerex_vc_height(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
				'js_view' => 'VcTrxTextView'
			) );
			
			class WPBakeryShortCode_Trx_Button extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Chat
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_chat",
				"name" => __("Chat", "themerex"),
				"description" => __("Chat message", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_chat',
				"class" => "trx_sc_single trx_sc_chat",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "title",
						"heading" => __("Item title", "themerex"),
						"description" => __("Title for current chat item", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "photo",
						"heading" => __("Item photo", "themerex"),
						"description" => __("Select or upload image or write URL from other site for the item photo (avatar)", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					array(
						"param_name" => "link",
						"heading" => __("Link URL", "themerex"),
						"description" => __("URL for the link on chat title click", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					
					array(
						"param_name" => "content",
						"heading" => __("Chat item content", "themerex"),
						"description" => __("Current chat item content", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textarea_html"
					),
					
					themerex_vc_width(),
					themerex_vc_height(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
				'js_view' => 'VcTrxTextView'
			
			) );
			
			class WPBakeryShortCode_Trx_Chat extends Themerex_Vc_ShortCodeSingle{}
			

			
			// Chart
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_chart",
				"name" => __("Chart", "themerex"),
				"description" => __("Chart items", "themerex"),
				"category" => __('Content', 'trx_utils'),
				"class" => "trx_sc_collection trx_sc_chart",
				'icon' => 'icon_trx_chart',
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => false,
				"as_parent" => array('only' => 'trx_chart_item'),
				"params" => array(
					array(
						"param_name" => "max_value",
						"heading" => __("Max value", "themerex"),
						"description" => __("Write max value of chart items", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => 100,
						"type" => "textfield"
					),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
				),
				'default_content' => '
					[trx_chart_item][/trx_chart_item]
				'
			) );
			
			
			vc_map( array(
				"base" => "trx_chart_item",
				"name" => __("Chart item", "themerex"),
				"description" => __("Chart item", "themerex"),
				"class" => "trx_sc_single trx_sc_chart_item",
				"show_settings_on_create" => true,
				"content_element" => true,
				"is_container" => false,
				'icon' => 'icon_trx_chart_item',
				"as_child" => array('only' => 'trx_chart'),
				"as_parent" => array('except' => 'trx_chart'),
				"params" => array(
					array(
						"param_name" => "value",
						"heading" => __("Value", "themerex"),
						"description" => __("Item value", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => 75,
						"type" => "textfield"
					),
					array(
						"param_name" => "value_color",
						"heading" => __("Value color", "themerex"),
						"description" => __("Text color for item value", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "#5cbece",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "color",
						"heading" => __("First color", "themerex"),
						"description" => __("Light item color", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "#89e1ee",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "dark_color",
						"heading" => __("Second color", "themerex"),
						"description" => __("Dark item color", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "#2a2f43",
						"type" => "colorpicker"
					),
					themerex_vc_width(190),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'] 
				)
			
			) );
			
			class WPBakeryShortCode_Trx_Chart extends Themerex_Vc_ShortCodeCollection {}
			class WPBakeryShortCode_Trx_Chart_Item extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Columns
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_columns",
				"name" => __("Columns", "themerex"),
				"description" => __("Insert columns with margins", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_columns',
				"class" => "trx_sc_columns",
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => false,
				"as_parent" => array('only' => 'trx_column_item'),
				"params" => array(
					array(
						"param_name" => "count",
						"heading" => __("Columns count", "themerex"),
						"description" => __("Number of the columns in the container.", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "2",
						"type" => "textfield"
					),
					array(
						"param_name" => "fluid",
						"heading" => __("Fluid columns", "themerex"),
						"description" => __("To squeeze the columns when reducing the size of the window (fluid=yes) or to rebuild them (fluid=no)", "themerex"),
						"class" => "",
						"value" => array(__('Fluid columns', 'trx_utils') => 'yes'),
						"type" => "checkbox"
					),
					themerex_vc_width(),
					themerex_vc_height(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
				'default_content' => '
					[trx_column_item][/trx_column_item]
					[trx_column_item][/trx_column_item]
				',
				'js_view' => 'VcTrxColumnsView'
			) );
			
			
			vc_map( array(
				"base" => "trx_column_item",
				"name" => __("Column", "themerex"),
				"description" => __("Column item", "themerex"),
				"show_settings_on_create" => true,
				"class" => "trx_sc_collection trx_sc_column_item",
				"content_element" => true,
				"is_container" => true,
				'icon' => 'icon_trx_column_item',
				"as_child" => array('only' => 'trx_columns'),
				"as_parent" => array('except' => 'trx_columns'),
				"params" => array(
					array(
						"param_name" => "span",
						"heading" => __("Merge columns", "themerex"),
						"description" => __("Count merged columns from current", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "align",
						"heading" => __("Alignment", "themerex"),
						"description" => __("Alignment text in the column", "themerex"),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['align']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "color",
						"heading" => __("Fore color", "themerex"),
						"description" => __("Any color for objects in this column", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "bg_color",
						"heading" => __("Background color", "themerex"),
						"description" => __("Any background color for this column", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "bg_image",
						"heading" => __("URL for background image file", "themerex"),
						"description" => __("Select or upload image or write URL from other site for the background", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
				'js_view' => 'VcTrxColumnItemView'
			) );
			
			class WPBakeryShortCode_Trx_Columns extends Themerex_Vc_ShortCodeColumns {}
			class WPBakeryShortCode_Trx_Column_Item extends Themerex_Vc_ShortCodeCollection {}
			

			
			// Contact form
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_contact_form",
				"name" => __("Contact form", "themerex"),
				"description" => __("Insert contact form", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_contact_form',
				"class" => "trx_sc_collection trx_sc_contact_form",
				"content_element" => true,
				"is_container" => true,
				"as_parent" => array('only' => 'trx_form_item'),
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "custom",
						"heading" => __("Custom", "themerex"),
						"description" => __("Use custom fields or create standard contact form (ignore info from 'Field' tabs)", "themerex"),
						"class" => "",
						"value" => array(__('Create custom form', 'trx_utils') => 'yes'),
						"type" => "checkbox"
					),
					array(
						"param_name" => "action",
						"heading" => __("Action", "themerex"),
						"description" => __("Contact form action (URL to handle form data). If empty - use internal action", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "align",
						"heading" => __("Alignment", "themerex"),
						"description" => __("Select form alignment", "themerex"),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['align']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "title",
						"heading" => __("Title", "themerex"),
						"description" => __("Title above contact form", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "description",
						"heading" => __("Description (under the title)", "themerex"),
						"description" => __("Contact form description", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textarea_html"
					),
					themerex_vc_width(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			
			vc_map( array(
				"base" => "trx_form_item",
				"name" => __("Form item (custom field)", "themerex"),
				"description" => __("Custom field for the contact form", "themerex"),
				"class" => "trx_sc_item trx_sc_form_item",
				'icon' => 'icon_trx_form_item',
				"allowed_container_element" => 'vc_row',
				"show_settings_on_create" => true,
				"content_element" => true,
				"is_container" => false,
				"as_child" => array('only' => 'trx_contact_form'), // Use only|except attributes to limit parent (separate multiple values with comma)
				"params" => array(
					array(
						"param_name" => "type",
						"heading" => __("Type", "themerex"),
						"description" => __("Select type of the custom field", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['field_types']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "name",
						"heading" => __("Name", "themerex"),
						"description" => __("Name of the custom field", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "value",
						"heading" => __("Default value", "themerex"),
						"description" => __("Default value of the custom field", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "label",
						"heading" => __("Label", "themerex"),
						"description" => __("Label for the custom field", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "label_position",
						"heading" => __("Label position", "themerex"),
						"description" => __("Label position relative to the field", "themerex"),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['label_positions']),
						"type" => "dropdown"
					),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			class WPBakeryShortCode_Trx_Contact_Form extends Themerex_Vc_ShortCodeCollection {}
			class WPBakeryShortCode_Trx_Form_Item extends Themerex_Vc_ShortCodeItem {}
			

			
			// Content block on fullscreen page
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_content",
				"name" => __("Content block", "themerex"),
				"description" => __("Container for main content block (use it only on fullscreen pages)", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_content',
				"class" => "trx_sc_collection trx_sc_content",
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => true,
				"params" => array(
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			class WPBakeryShortCode_Trx_Content extends Themerex_Vc_ShortCodeCollection {}
			

			
			// Countdown
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_countdown",
				"name" => __("Countdown", "themerex"),
				"description" => __("Insert countdown object", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_countdown',
				"class" => "trx_sc_single trx_sc_countdown",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "date",
						"heading" => __("Date", "themerex"),
						"description" => __("Upcoming date (format: yyyy-mm-dd)", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "time",
						"heading" => __("Time", "themerex"),
						"description" => __("Upcoming time (format: HH:mm:ss)", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "style",
						"heading" => __("Style", "themerex"),
						"description" => __("Countdown style", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							__('Style 1', 'trx_utils') => 1,
							__('Style 2', 'trx_utils') => 2,
							__('Style 3', 'trx_utils') => 3
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "align",
						"heading" => __("Alignment", "themerex"),
						"description" => __("Align counter to left, center or right", "themerex"),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['align']),
						"type" => "dropdown"
					),
					themerex_vc_width(),
					themerex_vc_height(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			class WPBakeryShortCode_Trx_Countdown extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Dropcaps
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_dropcaps",
				"name" => __("Dropcaps", "themerex"),
				"description" => __("Make first letter of the text as dropcaps", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_dropcaps',
				"class" => "trx_sc_single trx_sc_dropcaps",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "style",
						"heading" => __("Style", "themerex"),
						"description" => __("Dropcaps style", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							__('Style 1', 'trx_utils') => 1,
							__('Style 2', 'trx_utils') => 2,
							__('Style 3', 'trx_utils') => 3,
							__('Style 4', 'trx_utils') => 4
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "content",
						"heading" => __("Paragraph text", "themerex"),
						"description" => __("Paragraph with dropcaps content", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textarea_html"
					),
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
				'js_view' => 'VcTrxTextView'
			
			) );
			
			class WPBakeryShortCode_Trx_Dropcaps extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Emailer
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_emailer",
				"name" => __("E-mail collector", "themerex"),
				"description" => __("Collect e-mails into specified group", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_emailer',
				"class" => "trx_sc_single trx_sc_emailer",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "group",
						"heading" => __("Group", "themerex"),
						"description" => __("The name of group to collect e-mail address", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "open",
						"heading" => __("Opened", "themerex"),
						"description" => __("Initially open the input field on show object", "themerex"),
						"class" => "",
						"value" => array(__('Initially opened', 'trx_utils') => 'yes'),
						"type" => "checkbox"
					),
					array(
						"param_name" => "align",
						"heading" => __("Alignment", "themerex"),
						"description" => __("Align field to left, center or right", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['align']),
						"type" => "dropdown"
					),
					themerex_vc_width(),
					themerex_vc_height(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			class WPBakeryShortCode_Trx_Emailer extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Googlemap
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_googlemap",
				"name" => __("Google map", "themerex"),
				"description" => __("Insert Google map with desired address or coordinates", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_googlemap',
				"class" => "trx_sc_single trx_sc_googlemap",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "address",
						"heading" => __("Address", "themerex"),
						"description" => __("Address to show in map center", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "90 Merrion Square W, Dublin 2, Ireland",
						"type" => "textfield"
					),
					array(
						"param_name" => "latlng",
						"heading" => __("Latitude and Longtitude", "themerex"),
						"description" => __("Comma separated map center coorditanes (instead Address)", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "zoom",
						"heading" => __("Zoom", "themerex"),
						"description" => __("Map zoom factor", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "16",
						"type" => "textfield"
					),
					array(
						"param_name" => "style",
						"heading" => __("Style", "themerex"),
						"description" => __("Map custom style", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['googlemap_styles']),
						"type" => "dropdown"
					),
					themerex_vc_width('100%'),
					themerex_vc_height(240),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			class WPBakeryShortCode_Trx_Googlemap extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Grid
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_grid",
				"name" => __("Grid", "themerex"),
				"description" => __("Grid", "themerex"),
				"category" => __('Content', 'trx_utils'),
				"class" => "trx_sc_collection trx_sc_grid",
				'icon' => 'icon_trx_grid',
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => false,
				"as_parent" => array('only' => 'trx_grid_item'),
				"params" => array(
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			
			vc_map( array(
				"base" => "trx_grid_item",
				"name" => __("Grid item", "themerex"),
				"description" => __("Grid item", "themerex"),
				"class" => "trx_sc_collection trx_sc_grid_item",
				"show_settings_on_create" => true,
				"content_element" => true,
				"is_container" => true,
				'icon' => 'icon_trx_grid_item',
				"as_child" => array('only' => 'trx_grid'),
				"as_parent" => array('except' => 'trx_grid'),
				"params" => array(
					array(
						"param_name" => "width",
						"heading" => __("Layout", "themerex"),
						"description" => __("Select row layout.", "themerex"),
						"class" => "",
						"value" => array(
							__('Normal', 'trx_utils') => 1,
							__('Two widths', 'trx_utils') => 2,
							__('Three widths', 'trx_utils') => 3,
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "responsive",
						"heading" => __("Responsive", "themerex"),
						"description" => __("How to change the width of the element in responsive", "themerex"),
						"class" => "",
						"value" => array(
							__('Normal', 'trx_utils') => '',
							__('Smaller', 'trx_utils') => 'small',
							__('Bigger', 'trx_utils') => 'big',
						),
						"type" => "dropdown"
					),
				)
			
			) );
			
			class WPBakeryShortCode_Trx_Grid extends Themerex_Vc_ShortCodeColumns {}
			class WPBakeryShortCode_Trx_Grid_Item extends Themerex_Vc_ShortCodeCollection {}
			

			// Graph
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_graph",
				"name" => __("Graph", "themerex"),
				"description" => __("Graph items", "themerex"),
				"category" => __('Content', 'trx_utils'),
				"class" => "trx_sc_collection trx_sc_graph",
				'icon' => 'icon_trx_graph',
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => false,
				"as_parent" => array('only' => 'trx_graph_item'),
				"params" => array(
					array(
						"param_name" => "name",
						"heading" => __("Name", "themerex"),
						"description" => __("Graph name", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "Labels",
						"heading" => __("Labels", "themerex"),
						"description" => __("Insert labels separate with comma", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "Label1, Label2, Label3, Label4",
						"type" => "textfield"
					),
					themerex_vc_width(),
					themerex_vc_height(220),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
				)
			) );
			
			
			vc_map( array(
				"base" => "trx_graph_item",
				"name" => __("Graph item", "themerex"),
				"description" => __("Graph item", "themerex"),
				"class" => "trx_sc_single trx_sc_graph_item",
				"show_settings_on_create" => true,
				"content_element" => true,
				"is_container" => false,
				'icon' => 'icon_trx_graph_item',
				"as_child" => array('only' => 'trx_graph'),
				"as_parent" => array('except' => 'trx_graph'),
				"params" => array(
					array(
						"param_name" => "datas",
						"heading" => __("Datas", "themerex"),
						"description" => __("Insert datas separate with comma", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => 30,50,40,70,
						"type" => "textfield"
					),
					array(
						"param_name" => "color",
						"heading" => __("VColor", "themerex"),
						"description" => __("Item color", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "#76D3E1",
						"type" => "colorpicker"
					)
				)
			
			) );
			
			class WPBakeryShortCode_Trx_Graph extends Themerex_Vc_ShortCodeCollection {}
			class WPBakeryShortCode_Trx_Graph_Item extends Themerex_Vc_ShortCodeSingle {}
			
			
			// Highlight
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_highlight",
				"name" => __("Highlight text", "themerex"),
				"description" => __("Highlight text with selected color, background color and other styles", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_highlight',
				"class" => "trx_sc_single trx_sc_highlight",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "type",
						"heading" => __("Type", "themerex"),
						"description" => __("Highlight type", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array(
								__('Custom', 'trx_utils') => 0,
								__('Type 1', 'trx_utils') => 1,
								__('Type 2', 'trx_utils') => 2,
								__('Type 3', 'trx_utils') => 3
							),
						"type" => "dropdown"
					),
					array(
						"param_name" => "color",
						"heading" => __("Text color", "themerex"),
						"description" => __("Color for the highlighted text", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "bg_color",
						"heading" => __("Background color", "themerex"),
						"description" => __("Background color for the highlighted text", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "font_size",
						"heading" => __("Font size", "themerex"),
						"description" => __("Font size for the highlighted text (default - in pixels, allows any CSS units of measure)", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "content",
						"heading" => __("Highlight text", "themerex"),
						"description" => __("Content for highlight", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textarea_html"
					),
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
				'js_view' => 'VcTrxTextView'
			) );
			
			class WPBakeryShortCode_Trx_Highlight extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Icon
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_icon",
				"name" => __("Icon", "themerex"),
				"description" => __("Insert the icon", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_icon',
				"class" => "trx_sc_single trx_sc_icon",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "icon",
						"heading" => __("Icon", "themerex"),
						"description" => __("Select icon class from Fontello icons set", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => $THEMEREX_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					array(
						"param_name" => "color",
						"heading" => __("Text color", "themerex"),
						"description" => __("Icon's color", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "bg_color",
						"heading" => __("Background color", "themerex"),
						"description" => __("Background color for the icon", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "font_size",
						"heading" => __("Font size", "themerex"),
						"description" => __("Icon's font size", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "font_weight",
						"heading" => __("Font weight", "themerex"),
						"description" => __("Icon's font weight", "themerex"),
						"class" => "",
						"value" => array(
							__('Default', 'trx_utils') => 'inherit',
							__('Thin (100)', 'trx_utils') => '100',
							__('Light (300)', 'trx_utils') => '300',
							__('Normal (400)', 'trx_utils') => '400',
							__('Bold (700)', 'trx_utils') => '700'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "align",
						"heading" => __("Icon's alignment", "themerex"),
						"description" => __("Align icon to left, center or right", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['align']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "link",
						"heading" => __("Link URL", "themerex"),
						"description" => __("Link URL from this icon (if not empty)", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
			) );
			
			class WPBakeryShortCode_Trx_Icon extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Icon skills
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_icons_skills",
				"name" => __("Skills (icons)", "themerex"),
				"description" => __("Insert the skills block", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_icons_skills',
				"class" => "trx_sc_single trx_sc_icons_skills",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "icon",
						"heading" => __("Icon", "themerex"),
						"description" => __("Select icon class from Fontello icons set", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => $THEMEREX_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					array(
						"param_name" => "color",
						"heading" => __("Color", "themerex"),
						"description" => __("Icon's color", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "#67d3e0",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "size",
						"heading" => __("Font size", "themerex"),
						"description" => __("Icon's font size", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "count",
						"heading" => __("Count", "themerex"),
						"description" => __("Number of icons", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "10",
						"type" => "textfield"
					),
					array(
						"param_name" => "value",
						"heading" => __("Value", "themerex"),
						"description" => __("Number of colored icons", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "5",
						"type" => "textfield"
					),
					themerex_vc_width(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id']
				),
			) );
			
			class WPBakeryShortCode_Trx_Icons_Skills extends Themerex_Vc_ShortCodeSingle {}
			
			
			
			// Image
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_image",
				"name" => __("Image", "themerex"),
				"description" => __("Insert image", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_image',
				"class" => "trx_sc_single trx_sc_image",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "url",
						"heading" => __("Select image", "themerex"),
						"description" => __("Select image from library", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					array(
						"param_name" => "align",
						"heading" => __("Image alignment", "themerex"),
						"description" => __("Align image to left or right side", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['float']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "shape",
						"heading" => __("Image shape", "themerex"),
						"description" => __("Shape of the image: square or round", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							__('Square', 'trx_utils') => 'square',
							__('Round', 'trx_utils') => 'round'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "title",
						"heading" => __("Title", "themerex"),
						"description" => __("Image's title", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "icon",
						"heading" => __("Title's icon", "themerex"),
						"description" => __("Select icon for the title from Fontello icons set", "themerex"),
						"class" => "",
						"value" => $THEMEREX_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					themerex_vc_width(),
					themerex_vc_height(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			class WPBakeryShortCode_Trx_Image extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Infobox
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_infobox",
				"name" => __("Infobox", "themerex"),
				"description" => __("Box with info or error message", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_infobox',
				"class" => "trx_sc_single trx_sc_infobox",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "style",
						"heading" => __("Style", "themerex"),
						"description" => __("Infobox style", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array(
								__('Regular', 'trx_utils') => 'regular',
								__('Info', 'trx_utils') => 'info',
								__('Success', 'trx_utils') => 'success',
								__('Error', 'trx_utils') => 'error',
								__('Result', 'trx_utils') => 'result'
							),
						"type" => "dropdown"
					),
					array(
						"param_name" => "closeable",
						"heading" => __("Closeable", "themerex"),
						"description" => __("Create closeable box (with close button)", "themerex"),
						"class" => "",
						"value" => array(__('Close button', 'trx_utils') => 'yes'),
						"type" => "checkbox"
					),
					array(
						"param_name" => "icon",
						"heading" => __("Custom icon", "themerex"),
						"description" => __("Select icon for the infobox from Fontello icons set. If empty - use default icon", "themerex"),
						"class" => "",
						"value" => $THEMEREX_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					array(
						"param_name" => "color",
						"heading" => __("Text color", "themerex"),
						"description" => __("Any color for the text and headers", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "bg_color",
						"heading" => __("Background color", "themerex"),
						"description" => __("Any background color for this infobox", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "title",
						"heading" => __("Title", "themerex"),
						"description" => __("Infobox title", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "content",
						"heading" => __("Before title", "themerex"),
						"description" => __("Text before title", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textarea_html"
					),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			class WPBakeryShortCode_Trx_Infobox extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Islands
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_islands",
				"name" => __("Islands", "themerex"),
				"description" => __("Islands block", "themerex"),
				"category" => __('Content', 'trx_utils'),
				"class" => "trx_sc_collection trx_sc_islands",
				'icon' => 'icon_trx_islands',
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => false,
				"as_parent" => array('only' => 'trx_islands_item'),
				"params" => array(
					themerex_vc_width(),
					themerex_vc_height(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			
			vc_map( array(
				"base" => "trx_islands_item",
				"name" => __("Islands Item", "themerex"),
				"description" => __("Islands item", "themerex"),
				"class" => "trx_sc_single trx_sc_islands_item",
				"show_settings_on_create" => true,
				"content_element" => true,
				"is_container" => false,
				'icon' => 'icon_trx_islands_item',
				"as_child" => array('only' => 'trx_islands'),
				"as_parent" => array('except' => 'trx_islands'),
				"params" => array(
					array(
						"param_name" => "type",
						"heading" => __("Type", "themerex"),
						"description" => __("Choose type of island (min 1 max 4)", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "1",
						"type" => "textfield"
					),
					array(
						"param_name" => "value",
						"heading" => __("Value", "themerex"),
						"description" => __("Item value", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "color",
						"heading" => __("Color", "themerex"),
						"description" => __("Item color", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "#5cbece",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "left",
						"heading" => __("Left", "themerex"),
						"description" => __("Position from left in px or percent", "themerex"),
						"class" => "",
						"value" => "20%",
						"type" => "textfield"
					),
					array(
						"param_name" => "right",
						"heading" => __("Right", "themerex"),
						"description" => __("Position from right in px or percent", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
				)
			
			) );
			
			class WPBakeryShortCode_Trx_Islands extends Themerex_Vc_ShortCodeCollection {}
			class WPBakeryShortCode_Trx_Islands_Item extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Line
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_line",
				"name" => __("Line", "themerex"),
				"description" => __("Insert line (delimiter)", "themerex"),
				"category" => __('Content', 'trx_utils'),
				"class" => "trx_sc_single trx_sc_line",
				'icon' => 'icon_trx_line',
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "style",
						"heading" => __("Style", "themerex"),
						"description" => __("Line style", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array(
								__('Solid', 'trx_utils') => 'solid',
								__('Dashed', 'trx_utils') => 'dashed',
								__('Dotted', 'trx_utils') => 'dotted',
								__('Double', 'trx_utils') => 'double'
							),
						"type" => "dropdown"
					),
					array(
						"param_name" => "color",
						"heading" => __("Line color", "themerex"),
						"description" => __("Line color", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					themerex_vc_width(),
					themerex_vc_height(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			class WPBakeryShortCode_Trx_Line extends Themerex_Vc_ShortCodeSingle {}
			

			
			// List
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_list",
				"name" => __("List", "themerex"),
				"description" => __("List items with specific bullets", "themerex"),
				"category" => __('Content', 'trx_utils'),
				"class" => "trx_sc_collection trx_sc_list",
				'icon' => 'icon_trx_list',
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => false,
				"as_parent" => array('only' => 'trx_list_item'),
				"params" => array(
					array(
						"param_name" => "style",
						"heading" => __("Bullet's style", "themerex"),
						"description" => __("Bullet's style for each list item", "themerex"),
						"class" => "",
						"admin_label" => true,
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['list_styles']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "color",
						"heading" => __("Color", "themerex"),
						"description" => __("List items color", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "icon",
						"heading" => __("List icon", "themerex"),
						"description" => __("Select list icon from Fontello icons set (only for style=Iconed)", "themerex"),
						"admin_label" => true,
						"class" => "",
						'dependency' => array(
							'element' => 'style',
							'value' => array('iconed')
						),
						"value" => $THEMEREX_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					array(
						"param_name" => "icon_color",
						"heading" => __("Icon color", "themerex"),
						"description" => __("List icons color", "themerex"),
						"class" => "",
						'dependency' => array(
							'element' => 'style',
							'value' => array('iconed')
						),
						"value" => "",
						"type" => "colorpicker"
					),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
				'default_content' => '
					[trx_list_item]' . __( 'Item 1', 'trx_utils' ) . '[/trx_list_item]
					[trx_list_item]' . __( 'Item 2', 'trx_utils' ) . '[/trx_list_item]
				'
			) );
			
			
			vc_map( array(
				"base" => "trx_list_item",
				"name" => __("List item", "themerex"),
				"description" => __("List item with specific bullet", "themerex"),
				"class" => "trx_sc_single trx_sc_list_item",
				"show_settings_on_create" => true,
				"content_element" => true,
				"is_container" => false,
				'icon' => 'icon_trx_list_item',
				"as_child" => array('only' => 'trx_list'), // Use only|except attributes to limit parent (separate multiple values with comma)
				"as_parent" => array('except' => 'trx_list'),
				"params" => array(
					array(
						"param_name" => "title",
						"heading" => __("List item title", "themerex"),
						"description" => __("Title for the current list item (show it as tooltip)", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "link",
						"heading" => __("Link URL", "themerex"),
						"description" => __("Link URL for the current list item", "themerex"),
						"admin_label" => true,
						"group" => __('Link', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "target",
						"heading" => __("Link target", "themerex"),
						"description" => __("Link target for the current list item", "themerex"),
						"admin_label" => true,
						"group" => __('Link', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "color",
						"heading" => __("Color", "themerex"),
						"description" => __("Text color for this item", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "icon",
						"heading" => __("List item icon", "themerex"),
						"description" => __("Select list item icon from Fontello icons set (only for style=Iconed)", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => $THEMEREX_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					array(
						"param_name" => "icon_color",
						"heading" => __("Icon color", "themerex"),
						"description" => __("Icon color for this item", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "content",
						"heading" => __("List item text", "themerex"),
						"description" => __("Current list item content", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textarea_html"
					),
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
				'js_view' => 'VcTrxTextView'
			
			) );
			
			class WPBakeryShortCode_Trx_List extends Themerex_Vc_ShortCodeCollection {}
			class WPBakeryShortCode_Trx_List_Item extends Themerex_Vc_ShortCodeSingle {}
			


			// Quote
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_quote",
				"name" => __("Quote", "themerex"),
				"description" => __("Quote text", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_quote',
				"class" => "trx_sc_single trx_sc_quote",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "cite",
						"heading" => __("Quote cite", "themerex"),
						"description" => __("URL for the quote cite link", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "title",
						"heading" => __("Title (author)", "themerex"),
						"description" => __("Quote title (author name)", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "content",
						"heading" => __("Quote content", "themerex"),
						"description" => __("Quote content", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textarea_html"
					),
					themerex_vc_width(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
				'js_view' => 'VcTrxTextView'
			) );
			
			class WPBakeryShortCode_Trx_Quote extends Themerex_Vc_ShortCodeSingle {}
			

			// Rocks
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_rocks",
				"name" => __("Rocks", "themerex"),
				"description" => __("Rocks items", "themerex"),
				"category" => __('Content', 'trx_utils'),
				"class" => "trx_sc_collection trx_sc_rocks",
				'icon' => 'icon_trx_rocks',
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => false,
				"as_parent" => array('only' => 'trx_rocks_item'),
				"params" => array(
					array(
						"param_name" => "count",
						"heading" => __("Count", "themerex"),
						"description" => __("Count of items", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => 0,
						"type" => "textfield"
					),
					array(
						"param_name" => "maximum",
						"heading" => __("Max value", "themerex"),
						"description" => __("Write max value of rocks items", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => 0,
						"type" => "textfield"
					),
					themerex_vc_width(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id']
				)
			) );
			
			
			vc_map( array(
				"base" => "trx_rocks_item",
				"name" => __("Rocks item", "themerex"),
				"description" => __("Rocks item", "themerex"),
				"class" => "trx_sc_single trx_sc_rocks_item",
				"show_settings_on_create" => true,
				"content_element" => true,
				"is_container" => false,
				'icon' => 'icon_trx_rocks_item',
				"as_child" => array('only' => 'trx_rocks'),
				"as_parent" => array('except' => 'trx_rocks'),
				"params" => array(
					array(
						"param_name" => "title",
						"heading" => __("Title", "themerex"),
						"description" => __("Title of item", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "level",
						"heading" => __("Value", "themerex"),
						"description" => __("Item value", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					$THEMEREX_GLOBALS['vc_params']['id']
				)
			
			) );
			
			class WPBakeryShortCode_Trx_Rocks extends Themerex_Vc_ShortCodeCollection {}
			class WPBakeryShortCode_Trx_Rocks_Item extends Themerex_Vc_ShortCodeSingle {}



			// Search
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_search",
				"name" => __("Search form", "themerex"),
				"description" => __("Insert search form", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_search',
				"class" => "trx_sc_single trx_sc_search",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "style",
						"heading" => __("Style", "themerex"),
						"description" => __("Select style to display search field", "themerex"),
						"class" => "",
						"value" => array(
							__('Regular', 'trx_utils') => "regular",
							__('Flat', 'trx_utils') => "flat"
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "title",
						"heading" => __("Title", "themerex"),
						"description" => __("Title (placeholder) for the search field", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => __("Search &hellip;", 'trx_utils'),
						"type" => "textfield"
					),
					array(
						"param_name" => "ajax",
						"heading" => __("AJAX", "themerex"),
						"description" => __("Search via AJAX or reload page", "themerex"),
						"class" => "",
						"value" => array(__('Use AJAX search', 'trx_utils') => 'yes'),
						"type" => "checkbox"
					),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			class WPBakeryShortCode_Trx_Search extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Section
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_section",
				"name" => __("Section container", "themerex"),
				"description" => __("Container for any block ([block] analog - to enable nesting)", "themerex"),
				"category" => __('Content', 'trx_utils'),
				"class" => "trx_sc_collection trx_sc_section",
				'icon' => 'icon_trx_block',
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "dedicated",
						"heading" => __("Dedicated", "themerex"),
						"description" => __("Use this block as dedicated content - show it before post title on single page", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array(__('Use as dedicated content', 'trx_utils') => 'yes'),
						"type" => "checkbox"
					),
					array(
						"param_name" => "align",
						"heading" => __("Alignment", "themerex"),
						"description" => __("Select block alignment", "themerex"),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['align']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "bg_color",
						"heading" => __("Background color", "themerex"),
						"description" => __("Any background color for this section", "themerex"),
				//		"group" => __('Colors and Images', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "bg_image",
						"heading" => __("Background image URL", "themerex"),
						"description" => __("Select background image from library for this section", "themerex"),
				//		"group" => __('Colors and Images', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					array(
						"param_name" => "bg_padding",
						"heading" => __("Padding", "themerex"),
						"description" => __("Container padding", "themerex"),
					//	"group" => __('Colors and Images', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					themerex_vc_width(),
					themerex_vc_height(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			class WPBakeryShortCode_Trx_Section extends Themerex_Vc_ShortCodeCollection {}
			


			// Sidebar
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_sidebar",
				"name" => __("Sidebar", "themerex"),
				"description" => __("Insert sidebar", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_sidebar',
				"class" => "trx_sc_single trx_sc_sidebarp",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "name",
						"heading" => __("Name", "themerex"),
						"description" => __("Sidebar name", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "columns",
						"heading" => __("Columns", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right']
				)
			) );
			
			class WPBakeryShortCode_Trx_Sidebar extends Themerex_Vc_ShortCodeSingle {}



			// Skills
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_skills",
				"name" => __("Skills", "themerex"),
				"description" => __("Insert skills diagramm", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_skills',
				"class" => "trx_sc_collection trx_sc_skills",
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => true,
				"as_parent" => array('only' => 'trx_skills_item'),
				"params" => array(
					array(
						"param_name" => "max_value",
						"heading" => __("Max value", "themerex"),
						"description" => __("Max value for skills items", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "100",
						"type" => "textfield"
					),
					array(
						"param_name" => "type",
						"heading" => __("Skills type", "themerex"),
						"description" => __("Select type of skills block", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							__('Bar', 'trx_utils') => 'bar',
							__('Pie chart', 'trx_utils') => 'pie',
							__('Counter', 'trx_utils') => 'counter',
							__('Arc', 'trx_utils') => 'arc'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "layout",
						"heading" => __("Skills layout", "themerex"),
						"description" => __("Select layout of skills block", "themerex"),
						"admin_label" => true,
						'dependency' => array(
							'element' => 'type',
							'value' => array('counter','bar','pie')
						),
						"class" => "",
						"value" => array(
							__('Rows', 'trx_utils') => 'rows',
							__('Columns', 'trx_utils') => 'columns'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "dir",
						"heading" => __("Direction", "themerex"),
						"description" => __("Select direction of skills block", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['dir']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "style",
						"heading" => __("Counters style", "themerex"),
						"description" => __("Select style of skills items (only for type=counter)", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							__('Style 1', 'trx_utils') => '1',
							__('Style 2', 'trx_utils') => '2',
							__('Style 3', 'trx_utils') => '3',
							__('Style 4', 'trx_utils') => '4'
						),
						'dependency' => array(
							'element' => 'type',
							'value' => array('counter')
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "columns",
						"heading" => __("Columns count", "themerex"),
						"description" => __("Skills columns count (required)", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "2",
						"type" => "textfield"
					),
					array(
						"param_name" => "color",
						"heading" => __("Color", "themerex"),
						"description" => __("Color for all skills items", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "bg_color",
						"heading" => __("Background color", "themerex"),
						"description" => __("Background color for all skills items (only for type=pie)", "themerex"),
						'dependency' => array(
							'element' => 'type',
							'value' => array('pie')
						),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "border_color",
						"heading" => __("Border color", "themerex"),
						"description" => __("Border color for all skills items (only for type=pie)", "themerex"),
						'dependency' => array(
							'element' => 'type',
							'value' => array('pie')
						),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "title",
						"heading" => __("Title", "themerex"),
						"description" => __("Title of the skills block", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "subtitle",
						"heading" => __("Subtitle", "themerex"),
						"description" => __("Default subtitle of the skills block (only if type=arc)", "themerex"),
						'dependency' => array(
							'element' => 'type',
							'value' => array('arc')
						),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "align",
						"heading" => __("Alignment", "themerex"),
						"description" => __("Align skills block to left or right side", "themerex"),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['float']),
						"type" => "dropdown"
					),
					themerex_vc_width(),
					themerex_vc_height(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			
			vc_map( array(
				"base" => "trx_skills_item",
				"name" => __("Skill", "themerex"),
				"description" => __("Skills item", "themerex"),
				"show_settings_on_create" => true,
				"class" => "trx_sc_single trx_sc_skills_item",
				"content_element" => true,
				"is_container" => false,
				"as_child" => array('only' => 'trx_skills'),
				"as_parent" => array('except' => 'trx_skills'),
				"params" => array(
					array(
						"param_name" => "title",
						"heading" => __("Title", "themerex"),
						"description" => __("Title for the current skills item", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "value",
						"heading" => __("Value", "themerex"),
						"description" => __("Value for the current skills item", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "50",
						"type" => "textfield"
					),
					array(
						"param_name" => "color",
						"heading" => __("Color", "themerex"),
						"description" => __("Color for current skills item", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "bg_color",
						"heading" => __("Background color", "themerex"),
						"description" => __("Background color for current skills item (only for type=pie)", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "border_color",
						"heading" => __("Border color", "themerex"),
						"description" => __("Border color for current skills item (only for type=pie)", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "style",
						"heading" => __("Item style", "themerex"),
						"description" => __("Select style for the current skills item (only for type=counter)", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							__('Style 1', 'trx_utils') => '1',
							__('Style 2', 'trx_utils') => '2',
							__('Style 3', 'trx_utils') => '3',
							__('Style 4', 'trx_utils') => '4'
						),
						"type" => "dropdown"
					),
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			class WPBakeryShortCode_Trx_Skills extends Themerex_Vc_ShortCodeCollection {}
			class WPBakeryShortCode_Trx_Skills_Item extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Slider
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_slider",
				"name" => __("Slider", "themerex"),
				"description" => __("Insert slider", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_slider',
				"class" => "trx_sc_collection trx_sc_slider",
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => true,
				"as_parent" => array('only' => 'trx_slider_item'),
				"params" => array_merge(array(
					array(
						"param_name" => "engine",
						"heading" => __("Engine", "themerex"),
						"description" => __("Select engine for slider. Attention! Swiper is built-in engine, all other engines appears only if corresponding plugings are installed", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['sliders']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "align",
						"heading" => __("Float slider", "themerex"),
						"description" => __("Float slider to left or right side", "themerex"),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['float']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "custom",
						"heading" => __("Custom slides", "themerex"),
						"description" => __("Make custom slides from inner shortcodes (prepare it on tabs) or prepare slides from posts thumbnails", "themerex"),
						"class" => "",
						"value" => array(__('Custom slides', 'trx_utils') => 'yes'),
						"type" => "checkbox"
					)
					),
					themerex_exists_revslider() || themerex_exists_royalslider() ? array(
					array(
						"param_name" => "alias",
						"heading" => __("Revolution slider alias or Royal Slider ID", "themerex"),
						"description" => __("Alias for Revolution slider or Royal slider ID", "themerex"),
						"admin_label" => true,
						"class" => "",
						'dependency' => array(
							'element' => 'engine',
							'value' => array('revo','royal')
						),
						"value" => "",
						"type" => "textfield"
					)) : array(), array(
					array(
						"param_name" => "cat",
						"heading" => __("Categories list", "themerex"),
						"description" => __("Select category. If empty - show posts from any category or from IDs list", "themerex"),
						'dependency' => array(
							'element' => 'engine',
							'value' => array('swiper')
						),
						"class" => "",
						"value" => array_flip(themerex_array_merge(array(0 => __('- Select category -', 'trx_utils')), $THEMEREX_GLOBALS['sc_params']['categories'])),
						"type" => "dropdown"
					),
					array(
						"param_name" => "count",
						"heading" => __("Swiper: Number of posts", "themerex"),
						"description" => __("How many posts will be displayed? If used IDs - this parameter ignored.", "themerex"),
						'dependency' => array(
							'element' => 'engine',
							'value' => array('swiper')
						),
						"class" => "",
						"value" => "3",
						"type" => "textfield"
					),
					array(
						"param_name" => "offset",
						"heading" => __("Swiper: Offset before select posts", "themerex"),
						"description" => __("Skip posts before select next part.", "themerex"),
						'dependency' => array(
							'element' => 'engine',
							'value' => array('swiper')
						),
						"class" => "",
						"value" => "0",
						"type" => "textfield"
					),
					array(
						"param_name" => "orderby",
						"heading" => __("Swiper: Post sorting", "themerex"),
						"description" => __("Select desired posts sorting method", "themerex"),
						'dependency' => array(
							'element' => 'engine',
							'value' => array('swiper')
						),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['sorting']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "order",
						"heading" => __("Swiper: Post order", "themerex"),
						"description" => __("Select desired posts order", "themerex"),
						'dependency' => array(
							'element' => 'engine',
							'value' => array('swiper')
						),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['ordering']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "ids",
						"heading" => __("Swiper: Post IDs list", "themerex"),
						"description" => __("Comma separated list of posts ID. If set - parameters above are ignored!", "themerex"),
						'dependency' => array(
							'element' => 'engine',
							'value' => array('swiper')
						),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "controls",
						"heading" => __("Swiper: Show slider controls", "themerex"),
						"description" => __("Show arrows inside slider", "themerex"),
						'dependency' => array(
							'element' => 'engine',
							'value' => array('swiper')
						),
						"class" => "",
						"value" => array(__('Show controls', 'trx_utils') => 'yes'),
						"type" => "checkbox"
					),
					array(
						"param_name" => "pagination",
						"heading" => __("Swiper: Show slider pagination", "themerex"),
						"description" => __("Show bullets or titles to switch slides", "themerex"),
						"group" => __('Details', 'trx_utils'),
						'dependency' => array(
							'element' => 'engine',
							'value' => array('swiper')
						),
						"class" => "",
						"value" => array(
								__('Dots', 'trx_utils') => 'yes',
								__('Side Titles', 'trx_utils') => 'full',
								__('Over Titles', 'trx_utils') => 'over',
								__('None', 'trx_utils') => 'no'
							),
						"type" => "dropdown"
					),
					array(
						"param_name" => "titles",
						"heading" => __("Swiper: Show titles section", "themerex"),
						"description" => __("Show section with post's title and short post's description", "themerex"),
						"group" => __('Details', 'trx_utils'),
						'dependency' => array(
							'element' => 'engine',
							'value' => array('swiper')
						),
						"class" => "",
						"value" => array(
								__('Not show', 'trx_utils') => "no",
								__('Show/Hide info', 'trx_utils') => "slide",
								__('Fixed info', 'trx_utils') => "fixed"
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "descriptions",
						"heading" => __("Swiper: Post descriptions", "themerex"),
						"description" => __("Show post's excerpt max length (characters)", "themerex"),
						"group" => __('Details', 'trx_utils'),
						'dependency' => array(
							'element' => 'engine',
							'value' => array('swiper')
						),
						"class" => "",
						"value" => "0",
						"type" => "textfield"
					),
					array(
						"param_name" => "links",
						"heading" => __("Swiper: Post's title as link", "themerex"),
						"description" => __("Make links from post's titles", "themerex"),
						"group" => __('Details', 'trx_utils'),
						'dependency' => array(
							'element' => 'engine',
							'value' => array('swiper')
						),
						"class" => "",
						"value" => array(__('Titles as a links', 'trx_utils') => 'yes'),
						"type" => "checkbox"
					),
					array(
						"param_name" => "crop",
						"heading" => __("Swiper: Crop images", "themerex"),
						"description" => __("Crop images in each slide or live it unchanged", "themerex"),
						"group" => __('Details', 'trx_utils'),
						'dependency' => array(
							'element' => 'engine',
							'value' => array('swiper')
						),
						"class" => "",
						"value" => array(__('Crop images', 'trx_utils') => 'yes'),
						"type" => "checkbox"
					),
					array(
						"param_name" => "autoheight",
						"heading" => __("Swiper: Autoheight", "themerex"),
						"description" => __("Change whole slider's height (make it equal current slide's height)", "themerex"),
						"group" => __('Details', 'trx_utils'),
						'dependency' => array(
							'element' => 'engine',
							'value' => array('swiper')
						),
						"class" => "",
						"value" => array(__('Autoheight', 'trx_utils') => 'yes'),
						"type" => "checkbox"
					),
					array(
						"param_name" => "interval",
						"heading" => __("Swiper: Slides change interval", "themerex"),
						"description" => __("Slides change interval (in milliseconds: 1000ms = 1s)", "themerex"),
						"group" => __('Details', 'trx_utils'),
						'dependency' => array(
							'element' => 'engine',
							'value' => array('swiper')
						),
						"class" => "",
						"value" => "5000",
						"type" => "textfield"
					),
					themerex_vc_width(),
					themerex_vc_height(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				))
			) );
			
			
			vc_map( array(
				"base" => "trx_slider_item",
				"name" => __("Slide", "themerex"),
				"description" => __("Slider item - single slide", "themerex"),
				"show_settings_on_create" => true,
				"content_element" => true,
				"is_container" => false,
				'icon' => 'icon_trx_slider_item',
				"as_child" => array('only' => 'trx_slider'),
				"as_parent" => array('except' => 'trx_slider'),
				"params" => array(
					array(
						"param_name" => "src",
						"heading" => __("URL (source) for image file", "themerex"),
						"description" => __("Select or upload image or write URL from other site for the current slide", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			class WPBakeryShortCode_Trx_Slider extends Themerex_Vc_ShortCodeCollection {}
			class WPBakeryShortCode_Trx_Slider_Item extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Socials
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_socials",
				"name" => __("Social icons", "themerex"),
				"description" => __("Custom social icons", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_socials',
				"class" => "trx_sc_collection trx_sc_socials",
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => true,
				"as_parent" => array('only' => 'trx_social_item'),
				"params" => array_merge(array(
					array(
						"param_name" => "size",
						"heading" => __("Icon's size", "themerex"),
						"description" => __("Size of the icons", "themerex"),
						"class" => "",
						"value" => array(
							__('Tiny', 'trx_utils') => 'tiny',
							__('Small', 'trx_utils') => 'small',
							__('Large', 'trx_utils') => 'large'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "socials",
						"heading" => __("Manual socials list", "themerex"),
						"description" => __("Custom list of social networks. For example: twitter=http://twitter.com/my_profile|facebook=http://facebooc.com/my_profile. If empty - use socials from Theme options.", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "custom",
						"heading" => __("Custom socials", "themerex"),
						"description" => __("Make custom icons from inner shortcodes (prepare it on tabs)", "themerex"),
						"class" => "",
						"value" => array(__('Custom socials', 'trx_utils') => 'yes'),
						"type" => "checkbox"
					),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				))
			) );
			
			
			vc_map( array(
				"base" => "trx_social_item",
				"name" => __("Custom social item", "themerex"),
				"description" => __("Custom social item: name, profile url and icon url", "themerex"),
				"show_settings_on_create" => true,
				"content_element" => true,
				"is_container" => false,
				'icon' => 'icon_trx_social_item',
				"as_child" => array('only' => 'trx_socials'),
				"as_parent" => array('except' => 'trx_socials'),
				"params" => array(
					array(
						"param_name" => "name",
						"heading" => __("Social name", "themerex"),
						"description" => __("Name (slug) of the social network (twitter, facebook, linkedin, etc.)", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "url",
						"heading" => __("Your profile URL", "themerex"),
						"description" => __("URL of your profile in specified social network", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "icon",
						"heading" => __("URL (source) for icon file", "themerex"),
						"description" => __("Select or upload image or write URL from other site for the current social icon", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					)
				)
			) );
			
			class WPBakeryShortCode_Trx_Socials extends Themerex_Vc_ShortCodeCollection {}
			class WPBakeryShortCode_Trx_Social_Item extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Table
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_table",
				"name" => __("Table", "themerex"),
				"description" => __("Insert a table", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_table',
				"class" => "trx_sc_container trx_sc_table",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "align",
						"heading" => __("Cells content alignment", "themerex"),
						"description" => __("Select alignment for each table cell", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['align']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "content",
						"heading" => __("Table content", "themerex"),
						"description" => __("Content, created with any table-generator", "themerex"),
						"class" => "",
						"value" => "Paste here table content, generated on one of many public internet resources, for example: http://www.impressivewebs.com/html-table-code-generator/ or http://html-tables.com/",
						"type" => "textarea_html"
					),
					themerex_vc_width(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
				'js_view' => 'VcTrxTextContainerView'
			) );
			
			class WPBakeryShortCode_Trx_Table extends Themerex_Vc_ShortCodeContainer {}
			

			
			// Tabs
			//-------------------------------------------------------------------------------------
			
			$tab_id_1 = 'sc_tab_'.time() . '_1_' . rand( 0, 100 );
			$tab_id_2 = 'sc_tab_'.time() . '_2_' . rand( 0, 100 );
			vc_map( array(
				"base" => "trx_tabs",
				"name" => __("Tabs", "themerex"),
				"description" => __("Tabs", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_tabs',
				"class" => "trx_sc_collection trx_sc_tabs",
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => false,
				"as_parent" => array('only' => 'trx_tab'),
				"params" => array(
					array(
						"param_name" => "initial",
						"heading" => __("Initially opened tab", "themerex"),
						"description" => __("Number of initially opened tab", "themerex"),
						"class" => "",
						"value" => 1,
						"type" => "textfield"
					),
					array(
						"param_name" => "scroll",
						"heading" => __("Scroller", "themerex"),
						"description" => __("Use scroller to show tab content (height parameter required)", "themerex"),
						"class" => "",
						"value" => array("Use scroller" => "yes" ),
						"type" => "checkbox"
					),
					themerex_vc_width(),
					themerex_vc_height(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
				'default_content' => '
					[trx_tab title="' . __( 'Tab 1', 'trx_utils' ) . '" tab_id="'.esc_attr($tab_id_1).'"][/trx_tab]
					[trx_tab title="' . __( 'Tab 2', 'trx_utils' ) . '" tab_id="'.esc_attr($tab_id_2).'"][/trx_tab]
				',
				"custom_markup" => '
					<div class="wpb_tabs_holder wpb_holder vc_container_for_children">
						<ul class="tabs_controls">
						</ul>
						%content%
					</div>
				',
				'js_view' => 'VcTrxTabsView'
			) );
			
			
			vc_map( array(
				"base" => "trx_tab",
				"name" => __("Tab item", "themerex"),
				"description" => __("Single tab item", "themerex"),
				"show_settings_on_create" => true,
				"class" => "trx_sc_collection trx_sc_tab",
				"content_element" => true,
				"is_container" => true,
				'icon' => 'icon_trx_tab',
				"as_child" => array('only' => 'trx_tabs'),
				"as_parent" => array('except' => 'trx_tabs'),
				"params" => array(
					array(
						"param_name" => "title",
						"heading" => __("Tab title", "themerex"),
						"description" => __("Title for current tab", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "tab_id",
						"heading" => __("Tab ID", "themerex"),
						"description" => __("ID for current tab (required). Please, start it from letter.", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
			  'js_view' => 'VcTrxTabView'
			) );
			class WPBakeryShortCode_Trx_Tabs extends Themerex_Vc_ShortCodeTabs {}
			class WPBakeryShortCode_Trx_Tab extends Themerex_Vc_ShortCodeTab {}
			

			
			// Team
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_team",
				"name" => __("Team", "themerex"),
				"description" => __("Insert team members", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_team',
				"class" => "trx_sc_columns trx_sc_team",
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => true,
				"as_parent" => array('only' => 'trx_team_item'),
				"params" => array(
					array(
						"param_name" => "style",
						"heading" => __("Team style", "themerex"),
						"description" => __("Select style to display team members", "themerex"),
						"class" => "",
						"admin_label" => true,
						"value" => array(
							__('Style 1', 'trx_utils') => 1,
							__('Style 2', 'trx_utils') => 2
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "columns",
						"heading" => __("Columns", "themerex"),
						"description" => __("How many columns use to show team members", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "3",
						"type" => "textfield"
					),
					array(
						"param_name" => "custom",
						"heading" => __("Custom", "themerex"),
						"description" => __("Allow get team members from inner shortcodes (custom) or get it from specified group (cat)", "themerex"),
						"class" => "",
						"value" => array("Custom members" => "yes" ),
						"type" => "checkbox"
					),
					array(
						"param_name" => "cat",
						"heading" => __("Categories", "themerex"),
						"description" => __("Put here comma separated categories (ids or slugs) to show team members. If empty - select team members from any category (group) or from IDs list", "themerex"),
						"group" => __('Query', 'trx_utils'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "count",
						"heading" => __("Number of posts", "themerex"),
						"description" => __("How many posts will be displayed? If used IDs - this parameter ignored.", "themerex"),
						"group" => __('Query', 'trx_utils'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => "3",
						"type" => "textfield"
					),
					array(
						"param_name" => "offset",
						"heading" => __("Offset before select posts", "themerex"),
						"description" => __("Skip posts before select next part.", "themerex"),
						"group" => __('Query', 'trx_utils'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => "0",
						"type" => "textfield"
					),
					array(
						"param_name" => "orderby",
						"heading" => __("Post sorting", "themerex"),
						"description" => __("Select desired posts sorting method", "themerex"),
						"group" => __('Query', 'trx_utils'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['sorting']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "order",
						"heading" => __("Post order", "themerex"),
						"description" => __("Select desired posts order", "themerex"),
						"group" => __('Query', 'trx_utils'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['ordering']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "ids",
						"heading" => __("Team member's IDs list", "themerex"),
						"description" => __("Comma separated list of team members's ID. If set - parameters above (category, count, order, etc.)  are ignored!", "themerex"),
						"group" => __('Query', 'trx_utils'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
				'default_content' => '
					[trx_team_item user="' . __( 'Member 1', 'trx_utils' ) . '"][/trx_team_item]
					[trx_team_item user="' . __( 'Member 2', 'trx_utils' ) . '"][/trx_team_item]
				',
				'js_view' => 'VcTrxColumnsView'
			) );
			
			
			vc_map( array(
				"base" => "trx_team_item",
				"name" => __("Team member", "themerex"),
				"description" => __("Team member - all data pull out from it account on your site", "themerex"),
				"show_settings_on_create" => true,
				"class" => "trx_sc_item trx_sc_column_item trx_sc_team_item",
				"content_element" => true,
				"is_container" => false,
				'icon' => 'icon_trx_team_item',
				"as_child" => array('only' => 'trx_team'),
				"as_parent" => array('except' => 'trx_team'),
				"params" => array(
					array(
						"param_name" => "user",
						"heading" => __("Registered user", "themerex"),
						"description" => __("Select one of registered users (if present) or put name, position, etc. in fields below", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['users']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "member",
						"heading" => __("Team member", "themerex"),
						"description" => __("Select one of team members (if present) or put name, position, etc. in fields below", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['members']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "link",
						"heading" => __("Link", "themerex"),
						"description" => __("Link on team member's personal page", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "name",
						"heading" => __("Name", "themerex"),
						"description" => __("Team member's name", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "position",
						"heading" => __("Position", "themerex"),
						"description" => __("Team member's position", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "email",
						"heading" => __("E-mail", "themerex"),
						"description" => __("Team member's e-mail", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "photo",
						"heading" => __("Member's Photo", "themerex"),
						"description" => __("Team member's photo (avatar", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					array(
						"param_name" => "socials",
						"heading" => __("Socials", "themerex"),
						"description" => __("Team member's socials icons: name=url|name=url... For example: facebook=http://facebook.com/myaccount|twitter=http://twitter.com/myaccount", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			class WPBakeryShortCode_Trx_Team extends Themerex_Vc_ShortCodeColumns {}
			class WPBakeryShortCode_Trx_Team_Item extends Themerex_Vc_ShortCodeItem {}
			

			
			// Title
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_title",
				"name" => __("Title", "themerex"),
				"description" => __("Create header tag (1-6 level) with many styles", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_title',
				"class" => "trx_sc_single trx_sc_title",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "content",
						"heading" => __("Title content", "themerex"),
						"description" => __("Title content", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textarea_html"
					),
					array(
						"param_name" => "type",
						"heading" => __("Title type", "themerex"),
						"description" => __("Title type (header level)", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							__('Header 1', 'trx_utils') => '1',
							__('Header 2', 'trx_utils') => '2',
							__('Header 3', 'trx_utils') => '3',
							__('Header 4', 'trx_utils') => '4',
							__('Header 5', 'trx_utils') => '5',
							__('Header 6', 'trx_utils') => '6'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "style",
						"heading" => __("Title style", "themerex"),
						"description" => __("Title style: only text (regular) or with icon/image (iconed)", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							__('Regular', 'trx_utils') => 'regular',
							__('Underline', 'trx_utils') => 'underline',
							__('Divider', 'trx_utils') => 'divider',
							__('With icon (image)', 'trx_utils') => 'iconed'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "align",
						"heading" => __("Alignment", "themerex"),
						"description" => __("Title text alignment", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['align']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "font_size",
						"heading" => __("Font size", "themerex"),
						"description" => __("Custom font size. If empty - use theme default", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "font_weight",
						"heading" => __("Font weight", "themerex"),
						"description" => __("Custom font weight. If empty or inherit - use theme default", "themerex"),
						"class" => "",
						"value" => array(
							__('Default', 'trx_utils') => 'inherit',
							__('Thin (100)', 'trx_utils') => '100',
							__('Light (300)', 'trx_utils') => '300',
							__('Normal (400)', 'trx_utils') => '400',
							__('Semibold (600)', 'trx_utils') => '600',
							__('Bold (700)', 'trx_utils') => '700',
							__('Black (900)', 'trx_utils') => '900'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "color",
						"heading" => __("Title color", "themerex"),
						"description" => __("Select color for the title", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "font_family",
						"heading" => __("Font family", "themerex"),
						"description" => __("Custom font family", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "icon",
						"heading" => __("Title font icon", "themerex"),
						"description" => __("Select font icon for the title from Fontello icons set (if style=iconed)", "themerex"),
						"class" => "",
						"group" => __('Icon &amp; Image', 'trx_utils'),
						'dependency' => array(
							'element' => 'style',
							'value' => array('iconed')
						),
						"value" => $THEMEREX_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					array(
						"param_name" => "image",
						"heading" => __("or image icon", "themerex"),
						"description" => __("Select image icon for the title instead icon above (if style=iconed)", "themerex"),
						"class" => "",
						"group" => __('Icon &amp; Image', 'trx_utils'),
						'dependency' => array(
							'element' => 'style',
							'value' => array('iconed')
						),
						"value" => $THEMEREX_GLOBALS['sc_params']['images'],
						"type" => "dropdown"
					),
					array(
						"param_name" => "picture",
						"heading" => __("or select uploaded image", "themerex"),
						"description" => __("Select or upload image or write URL from other site (if style=iconed)", "themerex"),
						"group" => __('Icon &amp; Image', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					array(
						"param_name" => "image_size",
						"heading" => __("Image (picture) size", "themerex"),
						"description" => __("Select image (picture) size (if style=iconed)", "themerex"),
						"group" => __('Icon &amp; Image', 'trx_utils'),
						"class" => "",
						"value" => array(
							__('Small', 'trx_utils') => 'small',
							__('Medium', 'trx_utils') => 'medium',
							__('Large', 'trx_utils') => 'large'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "position",
						"heading" => __("Icon (image) position", "themerex"),
						"description" => __("Select icon (image) position (if style=iconed)", "themerex"),
						"group" => __('Icon &amp; Image', 'trx_utils'),
						"class" => "",
						"value" => array(
							__('Top', 'trx_utils') => 'top',
							__('Left', 'trx_utils') => 'left'
						),
						"type" => "dropdown"
					),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
				'js_view' => 'VcTrxTextView'
			) );
			
			class WPBakeryShortCode_Trx_Title extends Themerex_Vc_ShortCodeSingle {}
			

			// Text
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_text",
				"name" => __("Text", "themerex"),
				"description" => __("Insert text", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_text',
				"class" => "trx_sc_single trx_sc_text",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "content",
						"heading" => __("Text content", "themerex"),
						"description" => __("Text content", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textarea_html"
					),
					array(
						"param_name" => "url",
						"heading" => __("URL", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "align",
						"heading" => __("Alignment", "themerex"),
						"description" => __("Text alignment", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['align']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "font_size",
						"heading" => __("Font size", "themerex"),
						"description" => __("Custom font size. If empty - use theme default", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "font_weight",
						"heading" => __("Font weight", "themerex"),
						"description" => __("Custom font weight. If empty or inherit - use theme default", "themerex"),
						"class" => "",
						"value" => array(
							__('Default', 'trx_utils') => 'inherit',
							__('Thin (100)', 'trx_utils') => '100',
							__('Light (300)', 'trx_utils') => '300',
							__('Normal (400)', 'trx_utils') => '400',
							__('Semibold (600)', 'trx_utils') => '600',
							__('Bold (700)', 'trx_utils') => '700',
							__('Black (900)', 'trx_utils') => '900'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "color",
						"heading" => __("Text color", "themerex"),
						"description" => __("Select color for the text", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "background",
						"heading" => __("Text background", "themerex"),
						"description" => __("Select background for the text", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "spacing",
						"heading" => __("Font spacing", "themerex"),
						"description" => __("Custom font spacing", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "font_family",
						"heading" => __("Font family", "themerex"),
						"description" => __("Custom font family", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "icon",
						"heading" => __("Title font icon", "themerex"),
						"description" => __("Select font icon for the title from Fontello icons set (if style=iconed)", "themerex"),
						"class" => "",
						"group" => __('Icon &amp; Image', 'trx_utils'),
						'dependency' => array(
							'element' => 'style',
							'value' => array('iconed')
						),
						"value" => $THEMEREX_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id']
				),
				'js_view' => 'VcTrxTextView'
			) );
			
			class WPBakeryShortCode_Trx_Text extends Themerex_Vc_ShortCodeSingle {}



			// Toggles
			//-------------------------------------------------------------------------------------
				
			vc_map( array(
				"base" => "trx_toggles",
				"name" => __("Toggles", "themerex"),
				"description" => __("Toggles items", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_toggles',
				"class" => "trx_sc_collection trx_sc_toggles",
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => false,
				"as_parent" => array('only' => 'trx_toggles_item'),
				"params" => array(
					array(
						"param_name" => "counter",
						"heading" => __("Counter", "themerex"),
						"description" => __("Display counter before each toggles title", "themerex"),
						"class" => "",
						"value" => array("Add item numbers before each element" => "on" ),
						"type" => "checkbox"
					),
					array(
						"param_name" => "icon_closed",
						"heading" => __("Icon while closed", "themerex"),
						"description" => __("Select icon for the closed toggles item from Fontello icons set", "themerex"),
						"class" => "",
						"value" => $THEMEREX_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					array(
						"param_name" => "icon_opened",
						"heading" => __("Icon while opened", "themerex"),
						"description" => __("Select icon for the opened toggles item from Fontello icons set", "themerex"),
						"class" => "",
						"value" => $THEMEREX_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class']
				),
				'default_content' => '
					[trx_toggles_item title="' . __( 'Item 1 title', 'trx_utils' ) . '"][/trx_toggles_item]
					[trx_toggles_item title="' . __( 'Item 2 title', 'trx_utils' ) . '"][/trx_toggles_item]
				',
				"custom_markup" => '
					<div class="wpb_accordion_holder wpb_holder clearfix vc_container_for_children">
						%content%
					</div>
					<div class="tab_controls">
						<button class="add_tab" title="'.__("Add item", "themerex").'">'.__("Add item", "themerex").'</button>
					</div>
				',
				'js_view' => 'VcTrxTogglesView'
			) );
			
			
			vc_map( array(
				"base" => "trx_toggles_item",
				"name" => __("Toggles item", "themerex"),
				"description" => __("Single toggles item", "themerex"),
				"show_settings_on_create" => true,
				"content_element" => true,
				"is_container" => true,
				'icon' => 'icon_trx_toggles_item',
				"as_child" => array('only' => 'trx_toggles'),
				"as_parent" => array('except' => 'trx_toggles'),
				"params" => array(
					array(
						"param_name" => "title",
						"heading" => __("Title", "themerex"),
						"description" => __("Title for current toggles item", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "open",
						"heading" => __("Open on show", "themerex"),
						"description" => __("Open current toggle item on show", "themerex"),
						"class" => "",
						"value" => array("Opened" => "yes" ),
						"type" => "checkbox"
					),
					array(
						"param_name" => "icon_closed",
						"heading" => __("Icon while closed", "themerex"),
						"description" => __("Select icon for the closed toggles item from Fontello icons set", "themerex"),
						"class" => "",
						"value" => $THEMEREX_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					array(
						"param_name" => "icon_opened",
						"heading" => __("Icon while opened", "themerex"),
						"description" => __("Select icon for the opened toggles item from Fontello icons set", "themerex"),
						"class" => "",
						"value" => $THEMEREX_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
				'js_view' => 'VcTrxTogglesTabView'
			) );
			class WPBakeryShortCode_Trx_Toggles extends Themerex_Vc_ShortCodeToggles {}
			class WPBakeryShortCode_Trx_Toggles_Item extends Themerex_Vc_ShortCodeTogglesItem {}
			

			// Tooltip
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_tooltip",
				"name" => __("Tooltip", "themerex"),
				"description" => __("Insert tooltip", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_tooltip',
				"class" => "trx_sc_single trx_sc_tooltip",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "content",
						"heading" => __("Text content", "themerex"),
						"description" => __("Text content", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textarea_html"
					),
					array(
						"param_name" => "title",
						"heading" => __("Title", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			class WPBakeryShortCode_Trx_Tooltip extends Themerex_Vc_ShortCodeSingle {}


			// Vacancies
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_vacancies",
				"name" => __("Vacancies", "themerex"),
				"description" => __("Insert vacancies", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_vacancies',
				"class" => "trx_sc_single trx_sc_vacancies",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
				)
			) );
			
			class WPBakeryShortCode_Trx_Vacancies extends Themerex_Vc_ShortCodeSingle {}



			// Twitter
			//-------------------------------------------------------------------------------------

			vc_map( array(
				"base" => "trx_twitter",
				"name" => __("Twitter", "trx_utils"),
				"description" => __("Insert twitter feed into post (page)", "trx_utils"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_twitter',
				"class" => "trx_sc_single trx_sc_twitter",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "user",
						"heading" => __("Twitter Username", "trx_utils"),
						"description" => __("Your username in the twitter account. If empty - get it from Theme Options.", "trx_utils"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "consumer_key",
						"heading" => __("Consumer Key", "trx_utils"),
						"description" => __("Consumer Key from the twitter account", "trx_utils"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "consumer_secret",
						"heading" => __("Consumer Secret", "trx_utils"),
						"description" => __("Consumer Secret from the twitter account", "trx_utils"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "token_key",
						"heading" => __("Token Key", "trx_utils"),
						"description" => __("Token Key from the twitter account", "trx_utils"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "token_secret",
						"heading" => __("Token Secret", "trx_utils"),
						"description" => __("Token Secret from the twitter account", "trx_utils"),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "count",
						"heading" => __("Tweets number", "trx_utils"),
						"description" => __("Number tweets to show", "trx_utils"),
						"class" => "",
						"divider" => true,
						"value" => 3,
						"type" => "textfield"
					),
					array(
						"param_name" => "controls",
						"heading" => __("Show arrows", "trx_utils"),
						"description" => __("Show control buttons", "trx_utils"),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['yes_no']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "interval",
						"heading" => __("Tweets change interval", "trx_utils"),
						"description" => __("Tweets change interval (in milliseconds: 1000ms = 1s)", "trx_utils"),
						"class" => "",
						"value" => "7000",
						"type" => "textfield"
					),
					array(
						"param_name" => "align",
						"heading" => __("Alignment", "trx_utils"),
						"description" => __("Alignment of the tweets block", "trx_utils"),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['align']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "autoheight",
						"heading" => __("Autoheight", "trx_utils"),
						"description" => __("Change whole slider's height (make it equal current slide's height)", "trx_utils"),
						"class" => "",
						"value" => array("Autoheight" => "yes" ),
						"type" => "checkbox"
					),
					array(
						"param_name" => "bg_tint",
						"heading" => __("Background tint", "trx_utils"),
						"description" => __("Main background tint: dark or light", "trx_utils"),
						"group" => __('Colors and Images', 'trx_utils'),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['tint']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "bg_color",
						"heading" => __("Background color", "trx_utils"),
						"description" => __("Any background color for this section", "trx_utils"),
						"group" => __('Colors and Images', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "bg_image",
						"heading" => __("Background image URL", "trx_utils"),
						"description" => __("Select background image from library for this section", "trx_utils"),
						"group" => __('Colors and Images', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					array(
						"param_name" => "bg_overlay",
						"heading" => __("Overlay", "trx_utils"),
						"description" => __("Overlay color opacity (from 0.0 to 1.0)", "trx_utils"),
						"group" => __('Colors and Images', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "bg_texture",
						"heading" => __("Texture", "trx_utils"),
						"description" => __("Texture style from 1 to 11. Empty or 0 - without texture.", "trx_utils"),
						"group" => __('Colors and Images', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					themerex_vc_width(),
					themerex_vc_height(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				),
			) );

			class WPBakeryShortCode_Trx_Twitter extends Themerex_Vc_ShortCodeSingle {}


			// Video
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_video",
				"name" => __("Video", "themerex"),
				"description" => __("Insert video player", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_video',
				"class" => "trx_sc_single trx_sc_video",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "url",
						"heading" => __("URL for video file", "themerex"),
						"description" => __("Paste URL for video file", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "ratio",
						"heading" => __("Ratio", "themerex"),
						"description" => __("Select ratio for display video", "themerex"),
						"class" => "",
						"value" => array(
							__('16:9', 'trx_utils') => "16:9",
							__('4:3', 'trx_utils') => "4:3"
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "autoplay",
						"heading" => __("Autoplay video", "themerex"),
						"description" => __("Autoplay video on page load", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array("Autoplay" => "on" ),
						"type" => "checkbox"
					),
					array(
						"param_name" => "align",
						"heading" => __("Alignment", "themerex"),
						"description" => __("Select block alignment", "themerex"),
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['align']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "image",
						"heading" => __("Cover image", "themerex"),
						"description" => __("Select or upload image or write URL from other site for video preview", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					array(
						"param_name" => "bg_image",
						"heading" => __("Background image", "themerex"),
						"description" => __("Select or upload image or write URL from other site for video background. Attention! If you use background image - specify paddings below from background margins to video block in percents!", "themerex"),
						"group" => __('Background', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					array(
						"param_name" => "bg_top",
						"heading" => __("Top offset", "themerex"),
						"description" => __("Top offset (padding) from background image to video block (in percent). For example: 3%", "themerex"),
						"group" => __('Background', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "bg_bottom",
						"heading" => __("Bottom offset", "themerex"),
						"description" => __("Bottom offset (padding) from background image to video block (in percent). For example: 3%", "themerex"),
						"group" => __('Background', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "bg_left",
						"heading" => __("Left offset", "themerex"),
						"description" => __("Left offset (padding) from background image to video block (in percent). For example: 20%", "themerex"),
						"group" => __('Background', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "bg_right",
						"heading" => __("Right offset", "themerex"),
						"description" => __("Right offset (padding) from background image to video block (in percent). For example: 12%", "themerex"),
						"group" => __('Background', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					themerex_vc_width(),
					themerex_vc_height(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			class WPBakeryShortCode_Trx_Video extends Themerex_Vc_ShortCodeSingle {}
			

			
			// Zoom
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "trx_zoom",
				"name" => __("Zoom", "themerex"),
				"description" => __("Insert the image with zoom/lens effect", "themerex"),
				"category" => __('Content', 'trx_utils'),
				'icon' => 'icon_trx_zoom',
				"class" => "trx_sc_single trx_sc_zoom",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "effect",
						"heading" => __("Effect", "themerex"),
						"description" => __("Select effect to display overlapping image", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							__('Lens', 'trx_utils') => 'lens',
							__('Zoom', 'trx_utils') => 'zoom'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "url",
						"heading" => __("Main image", "themerex"),
						"description" => __("Select or upload main image", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					array(
						"param_name" => "over",
						"heading" => __("Overlaping image", "themerex"),
						"description" => __("Select or upload overlaping image", "themerex"),
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					array(
						"param_name" => "align",
						"heading" => __("Alignment", "themerex"),
						"description" => __("Float zoom to left or right side", "themerex"),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($THEMEREX_GLOBALS['sc_params']['float']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "bg_image",
						"heading" => __("Background image", "themerex"),
						"description" => __("Select or upload image or write URL from other site for zoom background. Attention! If you use background image - specify paddings below from background margins to video block in percents!", "themerex"),
						"group" => __('Background', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					array(
						"param_name" => "bg_top",
						"heading" => __("Top offset", "themerex"),
						"description" => __("Top offset (padding) from background image to zoom block (in percent). For example: 3%", "themerex"),
						"group" => __('Background', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "bg_bottom",
						"heading" => __("Bottom offset", "themerex"),
						"description" => __("Bottom offset (padding) from background image to zoom block (in percent). For example: 3%", "themerex"),
						"group" => __('Background', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "bg_left",
						"heading" => __("Left offset", "themerex"),
						"description" => __("Left offset (padding) from background image to zoom block (in percent). For example: 20%", "themerex"),
						"group" => __('Background', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "bg_right",
						"heading" => __("Right offset", "themerex"),
						"description" => __("Right offset (padding) from background image to zoom block (in percent). For example: 12%", "themerex"),
						"group" => __('Background', 'trx_utils'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					themerex_vc_width(),
					themerex_vc_height(),
					$THEMEREX_GLOBALS['vc_params']['margin_top'],
					$THEMEREX_GLOBALS['vc_params']['margin_bottom'],
					$THEMEREX_GLOBALS['vc_params']['margin_left'],
					$THEMEREX_GLOBALS['vc_params']['margin_right'],
					$THEMEREX_GLOBALS['vc_params']['id'],
					$THEMEREX_GLOBALS['vc_params']['class'],
					$THEMEREX_GLOBALS['vc_params']['animation'],
					$THEMEREX_GLOBALS['vc_params']['css']
				)
			) );
			
			class WPBakeryShortCode_Trx_Zoom extends Themerex_Vc_ShortCodeSingle {}
			

			do_action('themerex_action_shortcodes_list_vc');
		}
	}
}
?>